
include "mercenaries.xs";

void main(void)
{  
int version = 20060504;
/* 

Dogleg Islands by Jugit. First working beta version made on 10 Feb 2006.
                         First working version made on 12 Feb 2006.
                         First uploadable version made on 22 Feb 2006.
                         First revision completed on 27 Feb 2006.
                         Second revision completed on 9 Mar 2006
                         Third revision completed on 4 May 2006.
Things revised:

Revision 20060227

Moved any center player's water flags from edge of map nearer to them.
Added native village and extra gold mine to any last odd player's small island.
Changed far silver mines to gold.
Fixed bugs with the water flag and nugget placement for Nomad.
Made a slightly larger difference between the random small or large map.
Added a few more huntables.
Added some eye candy.

Revision 20060309

Made the small map smaller and the large map larger, and added a medium map size. The size is a random pick.
Added some close huntables.
Added bonus islands.
Played with the nugget difficulty, which I couldn't get to work properly.
Added detail text to "dogleg islands.xml".
Added some more eye candy.

Revision 20060504

Fixed herdable pick. Trade sockets now avoid water. Added nuggets to bonus islands.
Added pirates. Added BFG. Randomized mines better. Added another terrain type.
Hopefully fixed nugget difficulty, based them on the map type and added player nuggets.
Added pirate booty on bonus islands (500-1500 coin, food or wood).
Added random wagon(fort, covered, outpost, or factory) and LOS and conversion triggers.
Added bool flags to select game options(use/don't use pirates, bonus islands, etc).

To Do:

Update AI.

Index

I1.0 Constants and Initialization
     I1.1 Flags
     I1.2 Constants
     I1.3 Island, elbow and player positions.
     I1.4 Pirate ship routes
     I1.5 Identify human players.
     I1.6 Start native civilizations.
     I1.7 Select terrain and associated choices.
I2.0 Constraints
     I2.1 Type Distance Constraints
     I2.2 Terrain Constraints
     I2.3 Class Constraints
     I2.4 Misc Constraints
I3.0 Define Object
     I3.1 Player objects
     I3.2 Other objects
     I3.3 Nuggets
     I3.4 Nomad start objects.
     I3.5 Water objects
     I3.6 Bonus island objects.
     I3.7 BFG
     I3.8 Pirate ships.
I4.0 Make islands
     I4.1 Player islands
     I4.2 Elbow islands
     I4.3 Connection islands
I5.0 Position players
     I5.1 Place explorer or covered wagon for Nomad start.
     I5.2 Place Water Flags
     I5.3 Landing party placement
I6.0 Place Trade Routes
     I6.1 Placement order
     I6.2 Place pirate ships
     I6.3 Place surprise wagon(Fort, Outpost, Covered, or Factory)
     I6.4 Place trade routes
     I6.5 Place Natives
     I6.6 Place mines
     I6.7 Huntables, Herdables, Player trees and berries.
     I6.8 Nuggets
     I6.9 Remaining items.
I7.0 Triggers
     I7.1 Create triggers
     I7.2 Start trigger
     I7.3 FPS triggers.
     I7.4 Pirate ship triggers
     I7.5 Surprise triggers

I1.0 Start with Constants and Initialization */  rmSetStatusText("",0.01);

/* I1.1 Flags. Help troubleshoot, improve the frame rate or make the game more fun for the player.

   Game flags: you should only change one flag at a time. Be careful changing more. Some flags changes causes the game to change others.

   Diagnostic Flags */
   
   bool revealMapFlag        = false; // Normal = false. Set to true to reveal the map at the Welcome message.
   bool watchPiratesFlag     = false; // Normal = false. Set to true to be able to watch the pirate ships patrol the islands.
   bool useCountdownFlag     = false; // Normal = false. Used by the game during watchPiratesFlag to countdown the time to the next pirate ship move.
   bool useFPSCounterFlag    = false; // Normal = false. Set to true to display a countdown to measure the FPS with pause.

// Major function flags

   bool useTradeRoutesFlag   = true;  // Normal = true.  Set to false to prevent the creation of trade routes.
   bool useNativesFlag       = true;  // Normal = true.  Set to false to prevent the creation of native villages.
   bool usePiratesFlag       = true;  // Normal = true.  Set to false to prevent the placement and triggers for the pirate ships.
   bool useBonusIslandsFlag  = true;  // Normal = true.  Set to false to prevent the formation of the bonus islands.

// Preference flags

   bool useEyeCandyFlag      = true;  // Normal = true.  Set to false to eliminate a lot of the eye candy and improve frame rate about 10%.
   bool useBonusCratesFlag   = true;  // Normal = true.  Set to false to prevent the placement of the large crates (pirate booty) on the bonus islands.
   bool useBonusEyeCandyFlag = true;  // Normal = true.  Set to false to prevent bonus island eye candy. Game sets false with useEyeCandyFlag = false.
   bool useBonusGoldFlag     = true;  // Normal = true.  Set to false to prevent gold mines on bonus islands. Made for useBonusIslandsFlag = false.
   bool useNuggetsFlag       = true;  // Normal = true.  Set to false to prevent the placement of nuggets. Made for useSimpleMapFlag = false.
   bool useSurpriseFlag      = true;  // Normal = true.  True places a surprise on one of the bonus islands and sets its owner triggers.
   bool useBFGFlag           = true;  // Normal = true.  Set to false to prevent the placement of the BFG (Big Fixed Gun).
   bool useAttackMoveFlag    = true;  // Normal = true.  False means pirate ships won't attack as they move along the coast. Game sets false 1/2 the time.

// Map flags

   bool useSimpleMapFlag     = false; // Normal = false. Set to true to create a very simple map (no natives, trade routes, bonus islands, etc).
   bool useBasicMapFlag      = false; // Normal = false. Set to true to create a basic map (no bonus islands, no pirates, nor eyecandy).
   bool useSmallMapFlag      = false; // Normal = false. Set to true to only use a small map.  \   Only change one.
   bool useMediumMapFlag     = false; // Normal = false. Set to true to only use a medium map.  >  If you change more,
   bool useLargeMapFlag      = false; // Normal = false. Set to true to only use a large map.  /   the largest will be used.

// Misc flags

   bool multiPlayerFlag      = false; // Normal = false. Set to true for multiplayer games. Game will try to set it true for multiplayer.
   bool useBFGwithBaseFlag   = true;  // Normal = true.  Set to false for a plain fixed gun without the base. Game sets false for multiplayer.

// Flag adjustment. The game sets flags based on other flags. Adjust very carefully.

   if(useSimpleMapFlag == true)
  {
   useBonusIslandsFlag = false; useEyeCandyFlag = false; usePiratesFlag = false; useNativesFlag = false; useTradeRoutesFlag = false; useSmallMapFlag = true;
   useNuggetsFlag = false;
  }
   if(useBasicMapFlag == true)
  { useBonusIslandsFlag = false; useEyeCandyFlag = false; usePiratesFlag = false; }

   if(watchPiratesFlag == true)
  {
   revealMapFlag = true; usePiratesFlag = true; useCountdownFlag = true; useSmallMapFlag = true; useAttackMoveFlag = false;
  }
   if(useBonusIslandsFlag == false) { useBFGFlag = false; useBonusCratesFlag = false; useBonusEyeCandyFlag = false; }
   if(useEyeCandyFlag == false) useBonusEyeCandyFlag = false;
   if(rmRandInt(1,2) == 2) useAttackMoveFlag = false; // turns it off half the time anyway.

// I1.2 Set constants
   int players = cNumberNonGaiaPlayers;
   int islandCount = 4 + players/2 - rmRandInt(0,3);
   int pirateMoveTime = rmRandInt(120,240); int pirate1stMoveTime = pirateMoveTime; 
   if(watchPiratesFlag == true) { pirateMoveTime = 100; pirate1stMoveTime = 25; }
   int numElbows = 1; int numConnections = 2;
   if(players == 4 || players == 5){ numElbows = 2; numConnections = 4; }
   if(players == 6 || players == 7){ numElbows = 3; numConnections = 6; }
   if(players == 8){ numElbows = 4; numConnections = 8; }
   int pick = rmRandInt(1,8); if(players == 4 || players == 5) pick = rmRandInt(1,12); if(players > 5) pick = rmRandInt(1,18);
   int size = 200 + 75*players; int playerArea = 1750; float objectDistance = 42.0; int mapSizePick = rmRandInt(1,3);
   if(useSmallMapFlag == true) mapSizePick = 1; if(useMediumMapFlag == true) mapSizePick = 2; if(useLargeMapFlag == true) mapSizePick = 3;
   if(players == 7)  size = 725; // Same size as six player map since it is the same just a player in the very open middle.
   if(mapSizePick == 2) { size = 1.25*size;  playerArea = 1.25*1.25*playerArea; objectDistance = 1.25*objectDistance; }
   if(mapSizePick == 3) { size = 1.50*size; playerArea = 1.50*1.50*playerArea; objectDistance = 1.50*objectDistance; } // Largest map size = 1200.
   int bonusIslandSize = playerArea/2.5;

// I1.3 Initialize island, elbow and player positions
   float i1x  = 0.0; float i1z  = 0.0; float i2x  = 0.0; float i2z  = 0.0; float i3x  = 0.0; float i3z  = 0.0;
   float i4x  = 0.0; float i4z  = 0.0; float i5x  = 0.0; float i5z  = 0.0; float i6x  = 0.0; float i6z  = 0.0;
   float i7x  = 0.0; float i7z  = 0.0; float i8x  = 0.0; float i8z  = 0.0; float i9x  = 0.0; float i9z  = 0.0;
   float i10x = 0.0; float i10z = 0.0; float i11x = 0.0; float i11z = 0.0; float i12x = 0.0; float i12z = 0.0; float i13x = 0.0; float i13z = 0.0;
   float e1x  = 0.0; float e1z  = 0.0; float e2x  = 0.0; float e2z  = 0.0; float e3x  = 0.0; float e3z  = 0.0; float e4x  = 0.0; float e4z  = 0.0;
   float p1x  = 0.0; float p1z  = 0.0; float p2x  = 0.0; float p2z  = 0.0; float p3x  = 0.0; float p3z  = 0.0; float p4x  = 0.0; float p4z  = 0.0; 
   float p5x  = 0.0; float p5z  = 0.0; float p6x  = 0.0; float p6z  = 0.0; float p7x  = 0.0; float p7z  = 0.0; float p8x  = 0.0; float p8z  = 0.0;

// Set Island positions
   if(players < 4) 
 { i1x = 0.25; i1z = 0.50; i2x = 0.50; i2z = 0.75; i3x = 0.75; i3z = 0.50; i4x = 0.50; i4z = 0.25; }
   if(players == 4 || players == 5) 
 { i1x = 0.20; i1z = 0.50; i2x = 0.35; i2z = 0.76; i3x = 0.65; i3z = 0.76; i4x = 0.80; i4z = 0.50; i5x = 0.65; i5z = 0.24; i6x = 0.35; i6z = 0.24; }
   if(players > 5) 
 { i1x  = 0.15; i1z =  0.50; i2x  = 0.23; i2z  = 0.73; i3x  = 0.44; i3z =  0.84; i4x =  0.67; i4z  = 0.80;
   i5x  = 0.83; i5z =  0.62; i6x  = 0.83; i6z  = 0.38; i7x  = 0.67; i7z =  0.20; i8x =  0.44; i8z  = 0.16; i9x = 0.23; i9z = 0.27;
   i10x = 0.35; i10z = 0.50; i11x = 0.50; i11z = 0.65; i12x = 0.65; i12z = 0.50; i13x = 0.50; i13z = 0.35; }

// Pick player positions                      1234                     3412                 4123                  2341
   if(players < 4 && pick == 1) { p1x = i1x; p1z = i1z; p2x = i3x; p2z = i3z; p3x = i2x; p3z = i2z; e1x = i4x; e1z = i4z; }
   if(players < 4 && pick == 2) { p1x = i2x; p1z = i2z; p2x = i4x; p2z = i4z; p3x = i1x; p3z = i1z; e1x = i3x; e1z = i3z; }
   if(players < 4 && pick == 3) { p1x = i3x; p1z = i3z; p2x = i1x; p2z = i1z; p3x = i4x; p3z = i4z; e1x = i2x; e1z = i2z; }
   if(players < 4 && pick == 4) { p1x = i4x; p1z = i4z; p2x = i2x; p2z = i2z; p3x = i1x; p3z = i1z; e1x = i3x; e1z = i3z; }
   if(players < 4 && pick == 5) { p1x = i1x; p1z = i1z; p2x = i3x; p2z = i3z; p3x = i4x; p3z = i4z; e1x = i2x; e1z = i2z; }
   if(players < 4 && pick == 6) { p1x = i4x; p1z = i4z; p2x = i2x; p2z = i2z; p3x = i3x; p3z = i3z; e1x = i1x; e1z = i1z; }
   if(players < 4 && pick == 7) { p1x = i3x; p1z = i3z; p2x = i1x; p2z = i1z; p3x = i2x; p3z = i2z; e1x = i4x; e1z = i4z; }
   if(players < 4 && pick == 8) { p1x = i2x; p1z = i2z; p2x = i4x; p2z = i4z; p3x = i1x; p3z = i1z; e1x = i3x; e1z = i3z; }

   if((players == 4 || players == 5) && pick == 1)
 { p1x = i1x; p1z = i1z; p2x = i3x; p2z = i3z; p3x = i4x; p3z = i4z; p4x = i6x; p4z = i6z; e1x = i2x; e1z = i2z; e2x = i5x; e2z = i5z; }
   if((players == 4 || players == 5) && pick == 2)
 { p1x = i2x; p1z = i2z; p2x = i4x; p2z = i4z; p3x = i5x; p3z = i5z; p4x = i1x; p4z = i1z; e1x = i3x; e1z = i3z; e2x = i6x; e2z = i6z; }
   if((players == 4 || players == 5) && pick == 3)
 { p1x = i3x; p1z = i3z; p2x = i5x; p2z = i5z; p3x = i6x; p3z = i6z; p4x = i2x; p4z = i2z; e1x = i4x; e1z = i4z; e2x = i1x; e2z = i1z; }
   if((players == 4 || players == 5) && pick == 4)
 { p1x = i4x; p1z = i4z; p2x = i6x; p2z = i6z; p3x = i1x; p3z = i1z; p4x = i3x; p4z = i3z; e1x = i5x; e1z = i5z; e2x = i2x; e2z = i2z; }
   if((players == 4 || players == 5) && pick == 5)
 { p1x = i5x; p1z = i5z; p2x = i1x; p2z = i1z; p3x = i2x; p3z = i2z; p4x = i4x; p4z = i4z; e1x = i6x; e1z = i6z; e2x = i3x; e2z = i3z; }
   if((players == 4 || players == 5) && pick == 6)
 { p1x = i6x; p1z = i6z; p2x = i2x; p2z = i2z; p3x = i3x; p3z = i3z; p4x = i5x; p4z = i5z; e1x = i1x; e1z = i1z; e2x = i4x; e2z = i4z; }
   if((players == 4 || players == 5) && pick == 7)
 { p1x = i1x; p1z = i1z; p2x = i5x; p2z = i5z; p3x = i4x; p3z = i4z; p4x = i2x; p4z = i2z; e1x = i6x; e1z = i6z; e2x = i3x; e2z = i3z; }
   if((players == 4 || players == 5) && pick == 8)
 { p1x = i2x; p1z = i2z; p2x = i6x; p2z = i6z; p3x = i5x; p3z = i5z; p4x = i3x; p4z = i3z; e1x = i1x; e1z = i1z; e2x = i4x; e2z = i4z; }
   if((players == 4 || players == 5) && pick == 9)
 { p1x = i3x; p1z = i3z; p2x = i1x; p2z = i1z; p3x = i6x; p3z = i6z; p4x = i4x; p4z = i4z; e1x = i2x; e1z = i2z; e2x = i5x; e2z = i5z; }
   if((players == 4 || players == 5) && pick == 10)
 { p1x = i4x; p1z = i4z; p2x = i2x; p2z = i2z; p3x = i1x; p3z = i1z; p4x = i5x; p4z = i5z; e1x = i3x; e1z = i3z; e2x = i6x; e2z = i6z; }
   if((players == 4 || players == 5) && pick == 11)
 { p1x = i5x; p1z = i5z; p2x = i3x; p2z = i3z; p3x = i2x; p3z = i2z; p4x = i6x; p4z = i6z; e1x = i4x; e1z = i4z; e2x = i1x; e2z = i1z; }
   if((players == 4 || players == 5) && pick == 12)
 { p1x = i6x; p1z = i6z; p2x = i4x; p2z = i4z; p3x = i3x; p3z = i3z; p4x = i1x; p4z = i1z; e1x = i5x; e1z = i5z; e2x = i2x; e2z = i2z; }

   if(players == 5) { p5x = 0.5; p5z = 0.5; }

   if(players > 5)
{
   if(pick == 1)
 { p1x =  i1x; p1z =  i1z; p2x =  i3x; p2z =  i3z; p3x =  i4x; p3z = i4z; p4x = i6x; p4z = i6z; p5x = i7x;  p5z = i7z;  p6x =  i9x; p6z =  i9z;
   p7x = i11x; p7z = i11z; p8x = i13x; p8z = i13z; e1x =  i2x; e1z = i2z; e2x = i5x; e2z = i5z; e3x = i8x;  e3z = i8z;  e4x = i12x; e4z = i12z; }
   if(pick == 2)
 { p1x =  i2x; p1z =  i2z; p2x =  i4x; p2z =  i4z; p3x =  i5x; p3z = i5z; p4x = i7x; p4z = i7z; p5x = i8x;  p5z = i8z;  p6x = i1x;  p6z = i1z;
   p7x = i12x; p7z = i12z; p8x = i10x; p8z = i10z; e1x =  i3x; e1z = i3z; e2x = i6x; e2z = i6z; e3x = i9x;  e3z = i9z;  e4x = i11x; e4z = i11z; }
   if(pick == 3)
 { p1x =  i3x; p1z =  i3z; p2x =  i5x; p2z =  i5z; p3x =  i6x; p3z = i6z; p4x = i8x; p4z = i8z; p5x = i9x;  p5z = i9z;  p6x = i2x;  p6z = i2z;
   p7x = i13x; p7z = i13z; p8x = i11x; p8z = i11z; e1x = i4x;  e1z = i4z; e2x = i7x; e2z = i7z; e3x = i1x;  e3z = i1z;  e4x = i10x; e4z = i10z; }
   if(pick == 4)
 { p1x =  i4x; p1z =  i4z; p2x =  i6x; p2z =  i6z; p3x =  i7x; p3z = i7z; p4x = i9x; p4z = i9z; p5x = i1x;  p5z = i1z;  p6x = i3x;  p6z = i3z;
   p7x = i10x; p7z = i10z; p8x = i12x; p8z = i12z; e1x = i5x;  e1z = i5z; e2x = i8x; e2z = i8z; e3x = i2x;  e3z = i2z;  e4x = i13x; e4z = i13z; }
   if(pick == 5)
 { p1x =  i5x; p1z =  i5z; p2x =  i7x; p2z =  i7z; p3x =  i8x; p3z = i8z; p4x = i1x; p4z = i1z; p5x = i2x;  p5z = i2z;  p6x = i4x;  p6z = i4z;
   p7x = i11x; p7z = i11z; p8x = i13x; p8z = i13z; e1x = i6x;  e1z = i6z; e2x = i9x; e2z = i9z; e3x = i3x;  e3z = i3z;  e4x = i12x; e4z = i12z; }
   if(pick == 6)
 { p1x =  i6x; p1z =  i6z; p2x =  i8x; p2z =  i8z; p3x =  i9x; p3z = i9z; p4x = i2x; p4z = i2z; p5x = i3x;  p5z = i3z;  p6x = i5x;  p6z = i5z;
   p7x = i12x; p7z = i12z; p8x = i10x; p8z = i10z; e1x = i7x;  e1z = i7z; e2x = i1x; e2z = i1z; e3x = i4x;  e3z = i4z;  e4x = i13x; e4z = i13z; }
   if(pick == 7)
 { p1x =  i7x; p1z =  i7z; p2x =  i9x; p2z =  i9z; p3x =  i1x; p3z = i1z; p4x = i3x; p4z = i3z; p5x = i4x;  p5z = i4z;  p6x = i6x;  p6z = i6z;
   p7x = i13x; p7z = i13z; p8x = i11x; p8z = i11z; e1x = i8x;  e1z = i8z; e2x = i2x; e2z = i2z; e3x = i5x;  e3z = i5z;  e4x = i10x; e4z = i10z; }
   if(pick == 8)
 { p1x =  i8x; p1z =  i8z; p2x =  i1x; p2z =  i1z; p3x =  i2x; p3z = i2z; p4x = i4x; p4z = i4z; p5x = i5x;  p5z = i5z;  p6x = i7x;  p6z = i7z;
   p7x = i10x; p7z = i10z; p8x = i12x; p8z = i12z; e1x = i9x;  e1z = i9z; e2x = i3x; e2z = i3z; e3x = i6x;  e3z = i6z;  e4x = i11x; e4z = i11z; }
   if(pick == 9)
 { p1x =  i9x; p1z =  i9z; p2x =  i2x; p2z =  i2z; p3x =  i3x; p3z = i3z; p4x = i5x; p4z = i5z; p5x = i6x;  p5z = i6z;  p6x = i8x;  p6z = i8z;
   p7x = i10x; p7z = i10z; p8x = i12x; p8z = i12z; e1x = i1x;  e1z = i1z; e2x = i4x; e2z = i4z; e3x = i7x;  e3z = i7z;  e4x = i13x; e4z = i13z; }
   if(pick == 10)
 { p1x =  i1x; p1z =  i1z; p2x =  i8x; p2z =  i8z; p3x =  i7x; p3z = i7z; p4x = i5x; p4z = i5z; p5x = i4x;  p5z = i4z;  p6x =  i2x; p6z =  i2z;
   p7x = i10x; p7z = i10z; p8x = i12x; p8z = i12z; e1x =  i9x; e1z = i9z; e2x = i6x; e2z = i6z; e3x = i3x;  e3z = i3z;  e4x = i13x; e4z = i13z; }
   if(pick == 11)
 { p1x =  i9x; p1z =  i9z; p2x =  i7x; p2z =  i7z; p3x =  i6x; p3z = i6z; p4x = i4x; p4z = i4z; p5x = i3x;  p5z = i3z;  p6x = i1x;  p6z = i1z;
   p7x = i13x; p7z = i13z; p8x = i11x; p8z = i11z; e1x =  i8x; e1z = i8z; e2x = i5x; e2z = i5z; e3x = i2x;  e3z = i2z;  e4x = i12x; e4z = i12z; }
   if(pick == 12)
 { p1x =  i8x; p1z =  i8z; p2x =  i6x; p2z =  i6z; p3x =  i5x; p3z = i5z; p4x = i3x; p4z = i3z; p5x = i2x;  p5z = i2z;  p6x = i9x;  p6z = i9z;
   p7x = i12x; p7z = i12z; p8x = i10x; p8z = i10z; e1x = i7x;  e1z = i7z; e2x = i4x; e2z = i4z; e3x = i1x;  e3z = i1z;  e4x = i11x; e4z = i11z; }
   if(pick == 13)
 { p1x =  i7x; p1z =  i7z; p2x =  i5x; p2z =  i5z; p3x =  i4x; p3z = i4z; p4x = i2x; p4z = i2z; p5x = i1x;  p5z = i1z;  p6x = i8x;  p6z = i8z;
   p7x = i12x; p7z = i12z; p8x = i10x; p8z = i10z; e1x = i6x;  e1z = i6z; e2x = i3x; e2z = i3z; e3x = i9x;  e3z = i9z;  e4x = i13x; e4z = i13z; }
   if(pick == 14)
 { p1x =  i6x; p1z =  i6z; p2x =  i4x; p2z =  i4z; p3x =  i3x; p3z = i3z; p4x = i1x; p4z = i1z; p5x = i9x;  p5z = i9z;  p6x = i7x;  p6z = i7z;
   p7x = i11x; p7z = i11z; p8x = i13x; p8z = i13z; e1x = i5x;  e1z = i5z; e2x = i2x; e2z = i2z; e3x = i8x;  e3z = i8z;  e4x = i10x; e4z = i10z; }
   if(pick == 15)
 { p1x =  i5x; p1z =  i5z; p2x =  i3x; p2z =  i3z; p3x =  i2x; p3z = i2z; p4x = i9x; p4z = i9z; p5x = i8x;  p5z = i8z;  p6x = i6x;  p6z = i6z;
   p7x = i11x; p7z = i11z; p8x = i13x; p8z = i13z; e1x = i4x;  e1z = i4z; e2x = i1x; e2z = i1z; e3x = i7x;  e3z = i7z;  e4x = i12x; e4z = i12z; }
   if(pick == 16)
 { p1x =  i4x; p1z =  i4z; p2x =  i2x; p2z =  i2z; p3x =  i1x; p3z = i1z; p4x = i8x; p4z = i8z; p5x = i7x;  p5z = i7z;  p6x = i5x;  p6z = i5z;
   p7x = i11x; p7z = i11z; p8x = i13x; p8z = i13z; e1x = i3x;  e1z = i3z; e2x = i9x; e2z = i9z; e3x = i6x;  e3z = i6z;  e4x = i10x; e4z = i10z; }
   if(pick == 17)
 { p1x =  i3x; p1z =  i3z; p2x =  i1x; p2z =  i1z; p3x =  i9x; p3z = i9z; p4x = i7x; p4z = i7z; p5x = i6x;  p5z = i6z;  p6x = i4x;  p6z = i4z;
   p7x = i10x; p7z = i10z; p8x = i12x; p8z = i12z; e1x = i2x;  e1z = i2z; e2x = i8x; e2z = i8z; e3x = i5x;  e3z = i5z;  e4x = i13x; e4z = i13z; }
   if(pick == 18)
 { p1x =  i2x; p1z =  i2z; p2x =  i9x; p2z =  i9z; p3x =  i8x; p3z = i8z; p4x = i6x; p4z = i6z; p5x = i5x;  p5z = i5z;  p6x = i3x;  p6z = i3z;
   p7x = i10x; p7z = i10z; p8x = i12x; p8z = i12z; e1x = i1x;  e1z = i1z; e2x = i7x; e2z = i7z; e3x = i4x;  e3z = i4z;  e4x = i11x; e4z = i11z; }
}
   if(players == 7) { p7x = 0.5; p7z = 0.5; }

// I1.4 Set pirate ship routes

   float offset = rmRandFloat(1.2,2.1)*objectDistance/size; // Initial limits are 1.2 and 2.1.
   int routePick = rmRandInt(1,4);

                  float ps11x = e1x+offset; float ps11z = e1z;  float ps13x = e1x+offset; float ps13z = e1z;
                  float ps12x = p1x+offset; float ps12z = p1z;  float ps14x = p2x+offset; float ps14z = p2z;
                  float ps21x = e2x+offset; float ps21z = e2z;  float ps23x = e2x+offset; float ps23z = e2z;
                  float ps22x = p3x+offset; float ps22z = p3z;  float ps24x = p4x+offset; float ps24z = p4z;
                  float ps31x = e3x+offset; float ps31z = e3z;  float ps33x = e3x+offset; float ps33z = e3z;
                  float ps32x = p5x+offset; float ps32z = p5z;  float ps34x = p6x+offset; float ps34z = p6z;
                  float ps41x = e4x+offset; float ps41z = e4z;  float ps43x = e4x+offset; float ps43z = e4z;
                  float ps42x = p7x+offset; float ps42z = p7z;  float ps44x = p8x+offset; float ps44z = p8z;
   if(routePick == 2)
 { 
                        ps11x = e1x;              ps11z = e1z+offset; ps13x = e1x;              ps13z = e1z+offset;
                        ps12x = p1x;              ps12z = p1z+offset; ps14x = p2x;              ps14z = p2z+offset;
                        ps21x = e2x;              ps21z = e2z+offset; ps23x = e2x;              ps23z = e2z+offset;
                        ps22x = p3x;              ps22z = p3z+offset; ps24x = p4x;              ps24z = p4z+offset;
                        ps31x = e3x;              ps31z = e3z+offset; ps33x = e3x;              ps33z = e3z+offset;
                        ps32x = p5x;              ps32z = p5z+offset; ps34x = p6x;              ps34z = p6z+offset;
                        ps41x = e4x;              ps41z = e4z+offset; ps43x = e4x;              ps43z = e4z+offset;
                        ps42x = p7x;              ps42z = p7z+offset; ps44x = p8x;              ps44z = p8z+offset;
 }
   if(routePick == 3)
 {
                        ps11x = e1x-offset;       ps11z = e1z;        ps13x = e1x-offset;       ps13z = e1z;
                        ps12x = p1x-offset;       ps12z = p1z;        ps14x = p2x-offset;       ps14z = p2z;
                        ps21x = e2x-offset;       ps21z = e2z;        ps23x = e2x-offset;       ps23z = e2z;
                        ps22x = p3x-offset;       ps22z = p3z;        ps24x = p4x-offset;       ps24z = p4z;
                        ps31x = e3x-offset;       ps31z = e3z;        ps33x = e3x-offset;       ps33z = e3z;
                        ps32x = p5x-offset;       ps32z = p5z;        ps34x = p6x-offset;       ps34z = p6z;
                        ps41x = e4x-offset;       ps41z = e4z;        ps43x = e4x-offset;       ps43z = e4z;
                        ps42x = p7x-offset;       ps42z = p7z;        ps44x = p8x-offset;       ps44z = p8z;
 } 
   if(routePick == 4)
 {
                        ps11x = e1x;              ps11z = e1z-offset; ps13x = e1x;              ps13z = e1z-offset;
                        ps12x = p1x;              ps12z = p1z-offset; ps14x = p2x;              ps14z = p2z-offset;
                        ps21x = e2x;              ps21z = e2z-offset; ps23x = e2x;              ps23z = e2z-offset;
                        ps22x = p3x;              ps22z = p3z-offset; ps24x = p4x;              ps24z = p4z-offset;
                        ps31x = e3x;              ps31z = e3z-offset; ps33x = e3x;              ps33z = e3z-offset;
                        ps32x = p5x;              ps32z = p5z-offset; ps34x = p6x;              ps34z = p6z-offset;
                        ps41x = e4x;              ps41z = e4z-offset; ps43x = e4x;              ps43z = e4z-offset;
                        ps42x = p7x;              ps42z = p7z-offset; ps44x = p8x;              ps44z = p8z-offset;
 }              
   if(rmRandInt(1,2) == 2)
 {
   float pstx = ps12x; float pstz = ps12z; ps12x = ps14x; ps12z = ps14z; ps14x = pstx; ps14z = pstz;
         pstx = ps22x;       pstz = ps22z; ps22x = ps24x; ps22z = ps24z; ps24x = pstx; ps24z = pstz;
         pstx = ps32x;       pstz = ps32z; ps32x = ps34x; ps32z = ps34z; ps34x = pstx; ps34z = pstz;
         pstx = ps42x;       pstz = ps42z; ps42x = ps44x; ps42z = ps44z; ps44x = pstx; ps44z = pstz;
 }

// Last odd player routes.

   pick = rmRandInt(1,4);
   if(players == 3) 
 { 
   if(pick == 1) { ps21x = p3x; ps21z = p3z+offset; ps22x = p3x+offset; ps22z = p3z;
                   ps23x = p3x; ps23z = p3z-offset; ps24x = p3x-offset; ps24z = p3z; }
   if(pick == 2) { ps24x = p3x; ps24z = p3z+offset; ps23x = p3x+offset; ps23z = p3z;
                   ps22x = p3x; ps22z = p3z-offset; ps21x = p3x-offset; ps21z = p3z; }
   if(pick == 3) { ps23x = p3x; ps23z = p3z+offset; ps24x = p3x+offset; ps24z = p3z;
                   ps21x = p3x; ps21z = p3z-offset; ps22x = p3x-offset; ps22z = p3z; }
   if(pick == 4) { ps22x = p3x; ps22z = p3z+offset; ps21x = p3x+offset; ps21z = p3z;
                   ps24x = p3x; ps24z = p3z-offset; ps23x = p3x-offset; ps23z = p3z; }
 }
   if(players == 5) 
 { 
   if(pick == 1) { ps31x = 0.5; ps31z = 0.5+offset; ps32x = 0.5+offset; ps32z = 0.5;
                   ps33x = 0.5; ps33z = 0.5-offset; ps34x = 0.5-offset; ps34z = 0.5; }
   if(pick == 2) { ps34x = 0.5; ps34z = 0.5+offset; ps33x = 0.5+offset; ps33z = 0.5;
                   ps32x = 0.5; ps32z = 0.5-offset; ps31x = 0.5-offset; ps31z = 0.5; }
   if(pick == 3) { ps33x = 0.5; ps33z = 0.5+offset; ps34x = 0.5+offset; ps34z = 0.5;
                   ps31x = 0.5; ps31z = 0.5-offset; ps32x = 0.5-offset; ps32z = 0.5; }
   if(pick == 4) { ps32x = 0.5; ps32z = 0.5+offset; ps31x = 0.5+offset; ps31z = 0.5;
                   ps34x = 0.5; ps34z = 0.5-offset; ps33x = 0.5-offset; ps33z = 0.5; }
 }
   if(players == 7) 
 { 
   if(pick == 1) { ps41x = 0.5; ps41z = 0.5+offset; ps42x = 0.5+offset; ps42z = 0.5;
                   ps43x = 0.5; ps43z = 0.5-offset; ps44x = 0.5-offset; ps44z = 0.5; }
   if(pick == 2) { ps44x = 0.5; ps44z = 0.5+offset; ps43x = 0.5+offset; ps43z = 0.5;
                   ps42x = 0.5; ps42z = 0.5-offset; ps41x = 0.5-offset; ps41z = 0.5; }
   if(pick == 3) { ps43x = 0.5; ps43z = 0.5+offset; ps44x = 0.5+offset; ps44z = 0.5;
                   ps41x = 0.5; ps41z = 0.5-offset; ps42x = 0.5-offset; ps42z = 0.5; }
   if(pick == 4) { ps42x = 0.5; ps42z = 0.5+offset; ps41x = 0.5+offset; ps41z = 0.5;
                   ps44x = 0.5; ps44z = 0.5-offset; ps43x = 0.5-offset; ps43z = 0.5; }
 }
// I1.5 Identify human players. indetx = 1 human, identx = 0 computer.

   int ident0 = 1; int ident2 = 1; int ident3 = 1; int ident4 = 1; int ident5 = 1; int ident6 = 1; int ident7 = 1; int ident8 = 1; int identTotal = 0;
   for(i=2; <= players)
 {
   ident0 = 1;
   if(rmGetPlayerName(i) == "Queen Elizabeth" || rmGetPlayerName(i) == "Maurice of Nassau" || rmGetPlayerName(i) == "Napoleon" || 
   rmGetPlayerName(i) == "Suleiman" || rmGetPlayerName(i) == "Ivan the Terrible" || rmGetPlayerName(i) == "Frederick the Great" ||
   rmGetPlayerName(i) == "Henry the Navigator" || rmGetPlayerName(i) == "Queen Isabella" ) ident0 = 0;
   if(i == 2) ident2 = ident0; if(i == 3) ident3 = ident0; if(i == 4) ident4 = ident0; if(i == 5) ident5 = ident0;
   if(i == 6) ident6 = ident0; if(i == 7) ident7 = ident0; if(i == 8) ident8 = ident0;
   identTotal = identTotal + ident0;
 } 
   if(identTotal > 0) { multiPlayerFlag =true; useBFGwithBaseFlag = false; }

// Give nomad explorers wood. Decided not to but saving the command.

   // int woodAmount = 600; if(rmGetNomadStart()) rmAddPlayerResource(1, "wood", woodAmount);

// I1.6 Start native civilizations.

   int nativeSet = rmRandInt(1,4);
   int subCiv0=-1;
   int subCiv1=-1;
   int subCiv2=-1;
   int subCiv3=-1;
   if(nativeSet == 1)
{
   if(rmAllocateSubCivs(4) == true)
 {
   subCiv0=rmGetCivID("aztecs"); if (subCiv0 >= 0) rmSetSubCiv(0, "aztecs");
   subCiv1=rmGetCivID("caribs"); if (subCiv1 >= 0) rmSetSubCiv(1, "caribs");
   subCiv2=rmGetCivID("nootka"); if (subCiv2 >= 0) rmSetSubCiv(2, "nootka");
   subCiv3=rmGetCivID("tupi");   if (subCiv3 >= 0) rmSetSubCiv(3, "tupi");
 }
}
   if(nativeSet == 2)
{
   if(rmAllocateSubCivs(4) == true)
 {
   subCiv0=rmGetCivID("caribs"); if (subCiv0 >= 0) rmSetSubCiv(0, "caribs");
   subCiv1=rmGetCivID("nootka"); if (subCiv1 >= 0) rmSetSubCiv(1, "nootka");
   subCiv2=rmGetCivID("tupi");   if (subCiv2 >= 0) rmSetSubCiv(2, "tupi");
   subCiv3=rmGetCivID("aztecs"); if (subCiv3 >= 0) rmSetSubCiv(3, "aztecs");
 }
}
   if(nativeSet == 3)
{
   if(rmAllocateSubCivs(4) == true)
 {
   subCiv0=rmGetCivID("nootka"); if (subCiv0 >= 0) rmSetSubCiv(0, "nootka");
   subCiv1=rmGetCivID("tupi");   if (subCiv1 >= 0) rmSetSubCiv(1, "tupi");
   subCiv2=rmGetCivID("aztecs"); if (subCiv2 >= 0) rmSetSubCiv(2, "aztecs");
   subCiv3=rmGetCivID("caribs"); if (subCiv3 >= 0) rmSetSubCiv(3, "caribs");
 }
}
   if(nativeSet == 4)
{
   if(rmAllocateSubCivs(4) == true)
 {
   subCiv0=rmGetCivID("tupi");   if (subCiv0 >= 0) rmSetSubCiv(0, "tupi");
   subCiv1=rmGetCivID("aztecs"); if (subCiv1 >= 0) rmSetSubCiv(1, "aztecs");
   subCiv2=rmGetCivID("caribs"); if (subCiv2 >= 0) rmSetSubCiv(2, "caribs");
   subCiv3=rmGetCivID("nootka"); if (subCiv3 >= 0) rmSetSubCiv(3, "nootka");
 }
}
// Set the map size
   rmSetMapSize(size, size);

// I1.7 Select terrain and associated choices.
   string terrainCoast = "caribbean coast"; string terrainMix = "caribbean grass"; string forestType = "caribbean palm forest";
   string treeType = "treeCaribbean"; string TCDirt = "sonora_dirt"; string mapTypeName = "caribbean"; string huntablePick = "deer";
   pick = rmRandInt(1,4); if(pick == 2) { terrainCoast = "amazon river basin"; terrainMix = "amazon grass";
   forestType = "amazon rain forest"; treeType = "TreeAmazon"; TCDirt = "pampas_dirt"; mapTypeName = "amazonia"; huntablePick = "tapir";}
   if(pick == 3) { terrainCoast = "great lakes"; terrainMix = "saguenay tundra"; forestType = "saguenay forest"; treeType = "treesaguenay";
   TCDirt = "texas_dirt"; mapTypeName = "yucatan"; huntablePick = "elk"; }
   if(pick == 4) { terrainCoast = "Yucatan Coast"; terrainMix = "bayou_grass"; forestType = "Bayou Swamp Forest"; treeType = "treebayou";
   TCDirt = "bayou_forest"; mapTypeName = "bayou"; huntablePick = "turkey"; }
   pick = rmRandInt(1,3); string whaleType = "Beluga"; if(pick == 2) whaleType = "HumpbackWhale"; if(pick == 3) whaleType = "MinkeWhale"; 
   pick = rmRandInt(1,3); string herdablePick = "cow"; if(pick == 2) herdablePick = "llama"; if(pick == 3) herdablePick = "sheep";
   int specialPick =rmRandInt(1,5); string specialProp = "EaglesNest"; if(specialPick == 2) specialProp = "PropVulturePerching";
   if(specialPick == 3) specialProp = "PropEaglesRocks"; if(specialPick == 4) specialProp = "PropKingfisher"; 
   if(specialPick == 5) specialProp = "GroundPropsAm";
   pick = rmRandInt(1,3); string crateType = "CrateofFoodLarge"; if(pick == 2) crateType = "CrateofWoodLarge"; if(pick == 3) crateType = "CrateofCoinLarge";
   pick = rmRandInt(1,4); string surpriseName = "FortWagon"; if(pick == 2) surpriseName = "CoveredWagon"; 
   if(pick == 3) surpriseName = "OutpostWagon"; if(pick == 4) surpriseName = "FactoryWagon";
   rmSetSeaLevel(2.0);
   rmSetSeaType(terrainCoast);
   rmSetBaseTerrainMix(terrainMix);
   rmSetMapType("water");
   rmSetMapType("tropical");
   rmSetMapType(mapTypeName); // Uses either "amazonia", "bayou", "caribbean" or "yucatan"
   rmSetLightingSet("caribbean");

// rmSetWorldCircleConstraint(true);

// Init map.
   rmTerrainInitialize("water");

// Elevation
   rmSetMapElevationParameters(cElevTurbulence, 0.4, 6, 0.7, 5.0);
   rmSetMapElevationHeightBlend(0.2); // was 1
   rmSetSeaLevel(0.0);
   rmTerrainInitialize("water");
   rmSetMapType("water");
   rmSetWorldCircleConstraint(true);
   rmSetWindMagnitude(rmRandFloat(0.0,10.0));
   
   chooseMercs();

// Define some classes.
   int classKeyLand=rmDefineClass("keyLand");
   int classMainLand=rmDefineClass("mainLand");
   rmDefineClass("classForest");
   rmDefineClass("natives");

/* I2.0 Constraints */  rmSetStatusText("",0.2);

// -------------Define constraints

// I2.1 Type Distance Constraints

   int avoidTC15=rmCreateTypeDistanceConstraint("stay 15 away from TC", "TownCenter", 15.0);
   int avoidTC30=rmCreateTypeDistanceConstraint("stay 30 away from TC", "TownCenter", 30.0);
   int avoidTC150=rmCreateTypeDistanceConstraint("stay far away from TC", "TownCenter", 3*objectDistance);
   int avoidCW=rmCreateTypeDistanceConstraint("stay away from CW", "CoveredWagon", 15.0);
   int avoidAll=rmCreateTypeDistanceConstraint("avoid all", "all", 6.0);
   int avoidFlag = rmCreateTypeDistanceConstraint("avoid flag", "HomeCityWaterSpawnFlag", 50);
   int avoidSilver=rmCreateTypeDistanceConstraint("avoid silver mine", "mine", 10.0);
   int avoidGold=rmCreateTypeDistanceConstraint("avoid gold mine", "minegold", 10.0);
   int mineAvoidSilver=rmCreateTypeDistanceConstraint("mine avoid silver mine", "mine", 25.0);
   int mineAvoidGold=rmCreateTypeDistanceConstraint("mine avoid gold mine", "minegold", 25.0);
   int avoidGold30=rmCreateTypeDistanceConstraint("avoid gold mine by 30", "minegold", 30.0);
   int avoidFarGold=rmCreateTypeDistanceConstraint("avoid far gold mine", "minegold", 50.0);
   int fishVsMahi=rmCreateTypeDistanceConstraint("fish v Mahi", "fishMahi", 20.0);
   int fishVsTarpon=rmCreateTypeDistanceConstraint("fish v Tarpon", "fishTarpon", 20.0);
   int fishLand = rmCreateTerrainDistanceConstraint("fish land", "land", true, 8.0);
   int avoidNugget=rmCreateTypeDistanceConstraint("avoid nugget", "abstractNugget", 10.0);
   int avoidNuggetFar=rmCreateTypeDistanceConstraint("avoid nugget far", "abstractNugget", 50.0);
   int nuggetAvoidNugget=rmCreateTypeDistanceConstraint("nugget avoid nugget", "abstractNugget", 25.0);
   int whaleVsWhale=rmCreateTypeDistanceConstraint("whale v whale", whaleType, 50.0);
   int fishVsWhale=rmCreateTypeDistanceConstraint("fish v whale", whaleType, 20.0);
   int avoidHuntable=rmCreateTypeDistanceConstraint("avoid huntable", huntablePick, 25.0);
   int avoidHerdable=rmCreateTypeDistanceConstraint("avoid herdable", herdablePick, 20.0);
   int avoidRocks=rmCreateTypeDistanceConstraint("avoid rocks", "ShorelineRockBigNE", 4.0);
   int avoidDucks=rmCreateTypeDistanceConstraint("avoid ducks", "DuckFamily", 4.0);
   int avoidPlants=rmCreateTypeDistanceConstraint("avoid plants", "PlantsBay", 4.0);
   int avoidCrates=rmCreateTypeDistanceConstraint("avoid crates", crateType, 50.0);
   int avoidSurprise=rmCreateTypeDistanceConstraint("avoid surprise", surpriseName, 10.0);
   int avoidSpecialProp=rmCreateTypeDistanceConstraint("avoid special prop", specialProp, 10.0);
// I2.2 Terrain Constraints
   int flagLand = rmCreateTerrainDistanceConstraint("flag vs land", "land", true, 10.0);
   int avoidLand = rmCreateTerrainDistanceConstraint("avoid land", "land", true, 20.0);
   int avoidWater = rmCreateTerrainDistanceConstraint("avoid water medium", "Land", false, 8.0);
   int whaleLand = rmCreateTerrainDistanceConstraint("whale land", "land", true, 25.0);
   int nearShore=rmCreateTerrainMaxDistanceConstraint("stay near shore", "land", true, 15.0);
// I2.3 Class Constaints
   int forestConstraint=rmCreateClassDistanceConstraint("forest vs. forest", rmClassID("classForest"), 10.0);
   int avoidNatives=rmCreateClassDistanceConstraint("stuff avoids natives", rmClassID("natives"), 6.0);
   int avoidKeyLand = rmCreateClassDistanceConstraint("avoid player and elbow islands", classKeyLand, 10.0);
   int avoidMainLand = rmCreateClassDistanceConstraint("avoid main land", classMainLand, 20.0);
// I2.4 Misc Constraints
   int avoidTradeRoute = rmCreateTradeRouteDistanceConstraint("trade route", 6.0);
   int flagEdgeConstraint = rmCreatePieConstraint("flags stay near edge of map", 0.5, 0.5, rmGetMapXSize()-20, rmGetMapXSize()-10, 0, 0, 0);

// End of constraints -----------------------------------:)

/* I3.0 Define Objects */  rmSetStatusText("",0.3);

// I3.1 Player objects
// Player Trees	
   int treeID=rmCreateObjectDef("player trees"); rmAddObjectDefItem(treeID, treeType, 11, 7.0);
   rmSetObjectDefMinDistance(treeID, 20.0); rmSetObjectDefMaxDistance(treeID, 25.0);
   rmAddObjectDefConstraint(treeID, avoidAll); rmAddObjectDefConstraint(treeID, avoidTradeRoute);
// Berries
   int berryID=rmCreateObjectDef("berries"); rmAddObjectDefItem(berryID, "berryBush", rmRandInt(2,5), 3.0);
   rmSetObjectDefMinDistance(berryID, 15); rmSetObjectDefMaxDistance(berryID, 25);
   rmAddObjectDefConstraint(berryID, avoidAll); rmAddObjectDefConstraint(berryID, avoidTradeRoute);
// Player Mines
   int silverID = rmCreateObjectDef("random silver mine"); rmAddObjectDefItem(silverID, "mine", 1, 0);
   rmSetObjectDefMinDistance(silverID, 0.0); rmSetObjectDefMaxDistance(silverID, objectDistance);
   rmAddObjectDefConstraint(silverID, avoidTC15); rmAddObjectDefConstraint(silverID, avoidCW);
   rmAddObjectDefConstraint(silverID, avoidAll); rmAddObjectDefConstraint(silverID, mineAvoidSilver); 
   rmAddObjectDefConstraint(silverID, mineAvoidGold); rmAddObjectDefConstraint(silverID, avoidWater);
   rmAddObjectDefConstraint(silverID, avoidTradeRoute); rmAddObjectDefConstraint(silverID, avoidNatives);
// Player Huntables	
   int closeHuntableID=rmCreateObjectDef("close huntable herd"); rmAddObjectDefItem(closeHuntableID, huntablePick, rmRandInt(3,5), 5.0);
   rmSetObjectDefMinDistance(closeHuntableID, 15.0); rmSetObjectDefMaxDistance(closeHuntableID, 25);
   rmAddObjectDefConstraint(closeHuntableID, avoidAll); rmAddObjectDefConstraint(closeHuntableID, avoidHuntable);
   rmSetObjectDefCreateHerd(closeHuntableID, true);
// Bison carcass grouping. Using this to get some bird eye candy.
   int groupID = rmCreateGrouping("grouping object", "gp_carcass_bison");
   rmSetGroupingMinDistance(groupID, 15.0);
   rmSetGroupingMaxDistance(groupID, 25.0);
   rmAddGroupingConstraint(groupID, avoidTradeRoute);
   rmAddGroupingConstraint(groupID, avoidAll);
// I3.2 Other objects
// Other mines
   int goldID = rmCreateObjectDef("random gold mine"); rmAddObjectDefItem(goldID, "minegold", 1, 0);
   rmSetObjectDefMinDistance(goldID, 0.0); rmSetObjectDefMaxDistance(goldID, objectDistance);
   rmAddObjectDefConstraint(goldID, avoidTC15); rmAddObjectDefConstraint(goldID, avoidCW);
   rmAddObjectDefConstraint(goldID, avoidAll); rmAddObjectDefConstraint(goldID, mineAvoidSilver);
   rmAddObjectDefConstraint(goldID, mineAvoidGold); rmAddObjectDefConstraint(goldID, avoidWater);
   rmAddObjectDefConstraint(goldID, avoidTradeRoute); rmAddObjectDefConstraint(goldID, avoidNatives);
   int mineID = rmCreateObjectDef("global gold mine"); rmAddObjectDefItem(mineID, "minegold", 1, 0);
   rmSetObjectDefMinDistance(mineID, 0.0); rmSetObjectDefMaxDistance(mineID, rmXFractionToMeters(0.5));
   rmAddObjectDefConstraint(mineID, avoidMainLand); rmAddObjectDefConstraint(mineID, avoidFarGold);
   rmAddObjectDefConstraint(mineID, avoidWater);
// Other Huntables	
   int huntableID=rmCreateObjectDef("huntable herd"); rmAddObjectDefItem(huntableID, huntablePick, rmRandInt(3,5), 10.0);
   rmSetObjectDefMinDistance(huntableID, 0.0); rmSetObjectDefMaxDistance(huntableID, objectDistance);
   rmAddObjectDefConstraint(huntableID, avoidAll); rmAddObjectDefConstraint(huntableID, avoidHuntable);
   rmSetObjectDefCreateHerd(huntableID, true);
// Herdable 	
   int herdableID=rmCreateObjectDef("herdable"); rmAddObjectDefItem(herdableID, herdablePick, rmRandInt(2,3), 10.0);
   rmSetObjectDefMinDistance(herdableID, 20.0); rmSetObjectDefMaxDistance(herdableID, objectDistance);
   rmAddObjectDefConstraint(herdableID, avoidAll);
// Random trees
   int randomTreeID=rmCreateObjectDef("random tree"); rmAddObjectDefItem(randomTreeID, treeType, rmRandInt(1,3), 5.0);
   rmSetObjectDefMinDistance(randomTreeID, 0.0); rmSetObjectDefMaxDistance(randomTreeID, rmXFractionToMeters(0.5));
   rmAddObjectDefConstraint(randomTreeID, avoidTradeRoute);
   rmAddObjectDefConstraint(randomTreeID, avoidNatives); rmAddObjectDefConstraint(randomTreeID, avoidAll);
// I3.3 Nuggets
   int nuggetID=rmCreateObjectDef("nugget"); rmAddObjectDefItem(nuggetID, "Nugget", 1, 0.0);
   rmSetObjectDefMinDistance(nuggetID, 0.0); rmSetObjectDefMaxDistance(nuggetID, objectDistance);
   rmAddObjectDefConstraint(nuggetID, nuggetAvoidNugget); rmAddObjectDefConstraint(nuggetID, avoidTC30);
   rmAddObjectDefConstraint(nuggetID, avoidSilver); rmAddObjectDefConstraint(nuggetID, avoidGold);
   rmAddObjectDefConstraint(nuggetID, avoidTradeRoute); rmAddObjectDefConstraint(nuggetID, avoidWater);
   rmAddObjectDefConstraint(nuggetID, avoidNatives); rmAddObjectDefConstraint(nuggetID, avoidAll);
// Bonus Nuggets
   int bonusNuggetID=rmCreateObjectDef("bonus nugget"); rmAddObjectDefItem(bonusNuggetID, "Nugget", 1, 0.0);
   rmSetObjectDefMinDistance(bonusNuggetID, 0.0); rmSetObjectDefMaxDistance(bonusNuggetID, rmXFractionToMeters(0.5));
   rmAddObjectDefConstraint(bonusNuggetID, avoidNuggetFar); rmAddObjectDefConstraint(bonusNuggetID, avoidMainLand);
   rmAddObjectDefConstraint(bonusNuggetID, avoidSilver); rmAddObjectDefConstraint(bonusNuggetID, avoidGold);
   rmAddObjectDefConstraint(bonusNuggetID, avoidWater); rmAddObjectDefConstraint(bonusNuggetID, avoidSurprise);
// I3.4 Nomad start objects.
// Explorer
   int explorerID = rmCreateObjectDef("explorer"); rmAddObjectDefItem(explorerID, "explorer", 1, 0);
   rmSetObjectDefMinDistance(explorerID, 0.0); rmSetObjectDefMaxDistance(explorerID, 10.0);
// Settler
   int settlerID = rmCreateObjectDef("settler"); rmAddObjectDefItem(settlerID, "settler", 2, 5.0);
   rmSetObjectDefMinDistance(settlerID, 0.0); rmSetObjectDefMaxDistance(settlerID, 10.0);
// Mercenary
   int mercenaryID = rmCreateObjectDef("mercenary"); rmAddObjectDefItem(mercenaryID, "mercjaeger", 2, 5.0);
   rmSetObjectDefMinDistance(mercenaryID, 0.0); rmSetObjectDefMaxDistance(mercenaryID, 10.0);
// Surgeon
   int surgeonID = rmCreateObjectDef("surgeon"); rmAddObjectDefItem(surgeonID, "surgeon", 1, 5.0);
   rmSetObjectDefMinDistance(surgeonID, 0.0); rmSetObjectDefMaxDistance(surgeonID, 10.0);
// Caravel
   int caravelID = rmCreateObjectDef("caravel"); rmAddObjectDefItem(caravelID, "caravel", 1, 0);
   rmSetObjectDefMinDistance(caravelID, 0.0); rmSetObjectDefMaxDistance(caravelID, 10.0);
// Covered Wagon
   int coveredWagonID = rmCreateObjectDef("covered wagon"); rmAddObjectDefItem(coveredWagonID, "coveredwagon", 1, 0);
   rmSetObjectDefMinDistance(coveredWagonID, 0.0); rmSetObjectDefMaxDistance(coveredWagonID, 10.0);
// I3.5 Water objects
// Water Flag Fish (Supposedly helps AI decide to fish when fish are by their water flag.)
   int flagFishID=rmCreateObjectDef("flag fish"); rmAddObjectDefItem(flagFishID, "FishMahi", 3, 10.0);
   rmSetObjectDefMinDistance(flagFishID, 0.0); rmSetObjectDefMaxDistance(flagFishID, 10.0);
// Whales
   int whaleID=rmCreateObjectDef("whale"); 
   rmAddObjectDefItem(whaleID, whaleType, 1, 0.0);
   rmSetObjectDefMinDistance(whaleID, 0.0); rmSetObjectDefMaxDistance(whaleID, rmXFractionToMeters(0.45));
   rmAddObjectDefConstraint(whaleID, whaleVsWhale); rmAddObjectDefConstraint(whaleID, whaleLand);
   rmAddObjectDefConstraint(whaleID, avoidFlag);
// Fish
   int fishID=rmCreateObjectDef("fish Mahi"); rmAddObjectDefItem(fishID, "FishMahi", rmRandInt(2,3), 10.0);
   rmSetObjectDefMinDistance(fishID, 0.0); rmSetObjectDefMaxDistance(fishID, rmXFractionToMeters(0.5));
   rmAddObjectDefConstraint(fishID, fishVsMahi); rmAddObjectDefConstraint(fishID, fishVsWhale); 
   rmAddObjectDefConstraint(fishID, fishVsTarpon);
   int fish2ID=rmCreateObjectDef("fish Tarpon"); rmAddObjectDefItem(fish2ID, "FishTarpon", rmRandInt(2,3), 10.0);
   rmSetObjectDefMinDistance(fish2ID, 0.0); rmSetObjectDefMaxDistance(fish2ID, rmXFractionToMeters(0.5));
   rmAddObjectDefConstraint(fish2ID, fishVsMahi); rmAddObjectDefConstraint(fish2ID, fishVsTarpon);
   rmAddObjectDefConstraint(fish2ID, fishLand); rmAddObjectDefConstraint(fish2ID, fishVsWhale);
   rmAddObjectDefConstraint(fishID, fishLand);
// Coastal rocks
   int rockID=rmCreateObjectDef("Coastal Rocks"); rmAddObjectDefItem(rockID, "ShorelineRockBigNE", 1, 0);
   rmSetObjectDefMinDistance(rockID, 0.0); rmSetObjectDefMaxDistance(rockID, rmXFractionToMeters(0.4));
   rmAddObjectDefConstraint(rockID, nearShore); rmAddObjectDefConstraint(rockID, fishVsWhale);
   rmAddObjectDefConstraint(rockID, fishVsMahi); rmAddObjectDefConstraint(rockID, fishVsTarpon);
   rmAddObjectDefConstraint(rockID, fishLand);
// Duck family
   int ducksID=rmCreateObjectDef("duck family"); rmAddObjectDefItem(ducksID, "DuckFamily", 1, 0);
   rmSetObjectDefMinDistance(ducksID, 0.0); rmSetObjectDefMaxDistance(ducksID, rmXFractionToMeters(0.4));
   rmAddObjectDefConstraint(ducksID, nearShore); rmAddObjectDefConstraint(ducksID, fishVsWhale);
   rmAddObjectDefConstraint(ducksID, fishVsMahi); rmAddObjectDefConstraint(ducksID, fishVsTarpon);
   rmAddObjectDefConstraint(ducksID, fishLand); rmAddObjectDefConstraint(ducksID, avoidRocks);
// Water Plants
   int plantsID=rmCreateObjectDef("water plant"); rmAddObjectDefItem(plantsID, "PlantsBay", 3, 5.0);
   rmSetObjectDefMinDistance(plantsID, 0.0); rmSetObjectDefMaxDistance(plantsID, rmXFractionToMeters(0.4));
   rmAddObjectDefConstraint(plantsID, nearShore); rmAddObjectDefConstraint(plantsID, fishVsWhale);
   rmAddObjectDefConstraint(plantsID, fishVsMahi); rmAddObjectDefConstraint(plantsID, fishVsTarpon);
   rmAddObjectDefConstraint(plantsID, fishLand); rmAddObjectDefConstraint(plantsID, avoidRocks);
   rmAddObjectDefConstraint(plantsID, avoidDucks);
// Shipwreck
   int shipwreckID=rmCreateObjectDef("shipwreck"); rmAddObjectDefItem(shipwreckID, "IGCShipwreck", 1, 0);
   rmSetObjectDefMinDistance(shipwreckID, 0.0); rmSetObjectDefMaxDistance(shipwreckID, rmXFractionToMeters(0.4));
   rmAddObjectDefConstraint(shipwreckID, nearShore); rmAddObjectDefConstraint(shipwreckID, fishVsWhale);
   rmAddObjectDefConstraint(shipwreckID, fishVsMahi); rmAddObjectDefConstraint(shipwreckID, fishVsTarpon);
   rmAddObjectDefConstraint(shipwreckID, fishLand); rmAddObjectDefConstraint(shipwreckID, avoidRocks);
   rmAddObjectDefConstraint(shipwreckID, avoidDucks); rmAddObjectDefConstraint(shipwreckID, avoidPlants);
// I3.6 Bonus island objects.
// Island Huntable	
   int islandHuntableID=rmCreateObjectDef("island huntable herd"); rmAddObjectDefItem(islandHuntableID, huntablePick, rmRandInt(3,5), 5.0);
   rmSetObjectDefMinDistance(islandHuntableID, 0.0); rmSetObjectDefMaxDistance(islandHuntableID, rmXFractionToMeters(0.5));
   rmAddObjectDefConstraint(islandHuntableID, avoidMainLand); rmSetObjectDefCreateHerd(islandHuntableID, true);
// Bonus island special	prop
   int specialID=rmCreateObjectDef("island special prop"); rmAddObjectDefItem(specialID, specialProp, 1, 0);
   rmSetObjectDefMinDistance(specialID, 0.0); rmSetObjectDefMaxDistance(specialID, rmXFractionToMeters(0.5));
   rmAddObjectDefConstraint(specialID, avoidMainLand); rmAddObjectDefConstraint(specialID, avoidWater);
   rmAddObjectDefConstraint(specialID, avoidGold); rmAddObjectDefConstraint(specialID, avoidSurprise);
   rmAddObjectDefConstraint(specialID, avoidNugget); 
// Bonus island crate
   int crateID=rmCreateObjectDef("bonus island crate"); rmAddObjectDefItem(crateID, crateType, rmRandInt(1,3), 3.0);
   rmSetObjectDefMinDistance(crateID, 0.0); rmSetObjectDefMaxDistance(crateID, rmXFractionToMeters(0.5));
   rmAddObjectDefConstraint(crateID, avoidMainLand); rmAddObjectDefConstraint(crateID, avoidWater);
   rmAddObjectDefConstraint(crateID, avoidGold); rmAddObjectDefConstraint(crateID, avoidNugget);
   rmAddObjectDefConstraint(crateID, avoidCrates); rmAddObjectDefConstraint(crateID, avoidSurprise);

// I3.7 BFG
   if(useBFGwithBaseFlag == true)
 {
   int BFGID = rmCreateGrouping("big fixed gun", "FixedGun&Base");
   rmSetGroupingMinDistance(BFGID, 0.0); rmSetGroupingMaxDistance(BFGID, rmXFractionToMeters(0.5));
   rmAddGroupingConstraint(BFGID, avoidWater); rmAddGroupingConstraint(BFGID, avoidGold);
   rmAddGroupingConstraint(BFGID, avoidNugget); rmAddGroupingConstraint(BFGID, avoidMainLand); 
   rmAddGroupingConstraint(BFGID, forestConstraint); rmAddGroupingConstraint(BFGID, avoidTC150);
   rmAddGroupingConstraint(BFGID, avoidSurprise); rmAddGroupingConstraint(BFGID, avoidCrates);
   rmAddGroupingConstraint(BFGID, avoidSpecialProp);
 }
   if(useBFGwithBaseFlag == false)
 {
   int BFG1ID = rmCreateObjectDef("fixed gun no base"); rmAddObjectDefItem(BFG1ID, "SPCFixedGun", 1, 0);
   rmSetObjectDefMinDistance(BFG1ID, 0.0); rmSetObjectDefMaxDistance(BFG1ID, rmXFractionToMeters(0.5));
   rmAddObjectDefConstraint(BFG1ID, avoidWater); rmAddObjectDefConstraint(BFG1ID, avoidGold);
   rmAddObjectDefConstraint(BFG1ID, avoidNugget); rmAddObjectDefConstraint(BFG1ID, avoidMainLand);
   rmAddObjectDefConstraint(BFG1ID, forestConstraint); rmAddObjectDefConstraint(BFG1ID, avoidTC150);
   rmAddGroupingConstraint(BFG1ID, avoidSurprise); rmAddGroupingConstraint(BFG1ID, avoidCrates);
   rmAddGroupingConstraint(BFG1ID, avoidSpecialProp);
 }
// I3.8 Pirate ships.
// Pirate ship one
   int pirate1ID = rmCreateObjectDef("pirate ship one"); rmAddObjectDefItem(pirate1ID, "Privateer", 1, 0);
   rmSetObjectDefMinDistance(pirate1ID, objectDistance); rmSetObjectDefMaxDistance(pirate1ID, 2*objectDistance);
// Pirate ship two
   int pirate2ID = rmCreateObjectDef("pirate ship two"); rmAddObjectDefItem(pirate2ID, "Privateer", 1, 0);
   rmSetObjectDefMinDistance(pirate2ID, objectDistance); rmSetObjectDefMaxDistance(pirate2ID, 2*objectDistance);
// Pirate ship three
   int pirate3ID = rmCreateObjectDef("pirate ship three"); rmAddObjectDefItem(pirate3ID, "Privateer", 1, 0);
   rmSetObjectDefMinDistance(pirate3ID, objectDistance); rmSetObjectDefMaxDistance(pirate3ID, 2*objectDistance);
// Pirate ship four
   int pirate4ID = rmCreateObjectDef("pirate ship four"); rmAddObjectDefItem(pirate4ID, "Privateer", 1, 0);
   rmSetObjectDefMinDistance(pirate4ID, objectDistance); rmSetObjectDefMaxDistance(pirate4ID, 2*objectDistance);
// Fort wagon
   int surpriseID = rmCreateObjectDef("surprise"); rmAddObjectDefItem(surpriseID, surpriseName, 1, 0);
   rmSetObjectDefMinDistance(surpriseID, 0.0); rmSetObjectDefMaxDistance(surpriseID, rmXFractionToMeters(0.5));
   rmAddObjectDefConstraint(surpriseID, avoidMainLand); rmAddObjectDefConstraint(surpriseID, avoidWater);
   rmAddObjectDefConstraint(surpriseID, avoidGold); rmAddObjectDefConstraint(surpriseID, avoidNugget);
   rmAddObjectDefConstraint(surpriseID, avoidCrates);

/* I4.0 Make islands */  rmSetStatusText("",0.4);

// I4.1 Place player island sets.

   for(i=1; <= players)
  {
   int islandsID=rmCreateArea("island"+i);
   rmSetAreaSize(islandsID, rmAreaTilesToFraction(playerArea),  rmAreaTilesToFraction(playerArea));
   rmSetAreaMinBlobs(islandsID, 10); rmSetAreaMaxBlobs(islandsID, 15);
   rmSetAreaMinBlobDistance(islandsID, 8.0); rmSetAreaMaxBlobDistance(islandsID, 10.0);
   rmSetAreaCoherence(islandsID, 0.45); // was .55
   rmSetAreaBaseHeight(islandsID, 0.5);
   rmSetAreaSmoothDistance(islandsID, 20);
   rmSetAreaMix(islandsID, terrainMix);
   rmAddAreaToClass(islandsID, classKeyLand);
   rmAddAreaToClass(islandsID, classMainLand);
   rmAddAreaConstraint(islandsID, avoidKeyLand);
   rmSetAreaElevationType(islandsID, cElevTurbulence);
   rmSetAreaElevationVariation(islandsID, 4.0);
   rmSetAreaElevationMinFrequency(islandsID, 0.09);
   rmSetAreaElevationOctaves(islandsID, 3);
   rmSetAreaElevationPersistence(islandsID, 0.2);
   rmSetAreaElevationNoiseBias(islandsID, 1);
   rmSetAreaWarnFailure(islandsID, false);
   if (i == 1) rmSetAreaLocation(islandsID, p1x, p1z); if (i == 2) rmSetAreaLocation(islandsID, p2x, p2z);
   if (i == 3) rmSetAreaLocation(islandsID, p3x, p3z); if (i == 4) rmSetAreaLocation(islandsID, p4x, p4z);
   if (i == 5) rmSetAreaLocation(islandsID, p5x, p5z); if (i == 6) rmSetAreaLocation(islandsID, p6x, p6z);
   if (i == 7) rmSetAreaLocation(islandsID, p7x, p7z); if (i == 8) rmSetAreaLocation(islandsID, p8x, p8z);
  }
// I4.2Place elbow island sets.

   for(i=1; <= numElbows)
  {
   int elbowIslandID=rmCreateArea("elbow island"+i);
   rmSetAreaSize(elbowIslandID, rmAreaTilesToFraction(playerArea),  rmAreaTilesToFraction(playerArea));
   rmSetAreaMinBlobs(elbowIslandID, 10); rmSetAreaMaxBlobs(elbowIslandID, 15);
   rmSetAreaMinBlobDistance(elbowIslandID, 8.0); rmSetAreaMaxBlobDistance(elbowIslandID, 10.0);
   rmSetAreaCoherence(elbowIslandID, 0.45); // was .55
   rmSetAreaBaseHeight(elbowIslandID, 4.5);
   rmSetAreaSmoothDistance(elbowIslandID, 20);
   rmSetAreaMix(elbowIslandID, terrainMix);
   rmAddAreaToClass(elbowIslandID, classKeyLand);
   rmAddAreaToClass(elbowIslandID, classMainLand);
   rmAddAreaConstraint(elbowIslandID, avoidKeyLand);
   rmSetAreaElevationType(elbowIslandID, cElevTurbulence);
   rmSetAreaElevationVariation(elbowIslandID, 4.0);
   rmSetAreaElevationMinFrequency(elbowIslandID, 0.09);
   rmSetAreaElevationOctaves(elbowIslandID, 3);
   rmSetAreaElevationPersistence(elbowIslandID, 0.2);
   rmSetAreaElevationNoiseBias(elbowIslandID, 1);
   rmSetAreaWarnFailure(elbowIslandID, false);
   if (i == 1) rmSetAreaLocation(elbowIslandID, e1x, e1z); if (i == 2) rmSetAreaLocation(elbowIslandID, e2x, e2z);
   if (i == 3) rmSetAreaLocation(elbowIslandID, e3x, e3z); if (i == 4) rmSetAreaLocation(elbowIslandID, e4x, e4z);
  }
// I4.3Place connection islands

   for(i=1; <= numConnections)
  {
   int connectIslandID=rmCreateArea("connect island"+i);
   rmSetAreaSize(connectIslandID, rmAreaTilesToFraction(playerArea),  rmAreaTilesToFraction(playerArea));
   rmSetAreaMinBlobs(connectIslandID, 10); rmSetAreaMaxBlobs(connectIslandID, 15);
   rmSetAreaMinBlobDistance(connectIslandID, 8.0); rmSetAreaMaxBlobDistance(connectIslandID, 10.0);
   rmSetAreaCoherence(connectIslandID, 0.45); // was .55
   rmSetAreaBaseHeight(connectIslandID, 2.5);
   rmSetAreaSmoothDistance(connectIslandID, 20);
   rmSetAreaMix(connectIslandID, terrainMix);
   rmAddAreaToClass(connectIslandID, classMainLand);
   rmSetAreaElevationType(connectIslandID, cElevTurbulence);
   rmSetAreaElevationVariation(connectIslandID, 4.0);
   rmSetAreaElevationMinFrequency(connectIslandID, 0.09);
   rmSetAreaElevationOctaves(connectIslandID, 3);
   rmSetAreaElevationPersistence(connectIslandID, 0.2);
   rmSetAreaElevationNoiseBias(connectIslandID, 1);
   rmSetAreaWarnFailure(connectIslandID, false);
   if (i == 1) rmSetAreaLocation(connectIslandID, (p1x + e1x)/2, (p1z + e1z)/2);
   if (i == 2) rmSetAreaLocation(connectIslandID, (p2x + e1x)/2, (p2z + e1z)/2);
   if (i == 3) rmSetAreaLocation(connectIslandID, (p3x + e2x)/2, (p3z + e2z)/2);
   if (i == 4) rmSetAreaLocation(connectIslandID, (p4x + e2x)/2, (p4z + e2z)/2);
   if (i == 5) rmSetAreaLocation(connectIslandID, (p5x + e3x)/2, (p5z + e3z)/2);
   if (i == 6) rmSetAreaLocation(connectIslandID, (p6x + e3x)/2, (p6z + e3z)/2);
   if (i == 7) rmSetAreaLocation(connectIslandID, (p7x + e4x)/2, (p7z + e4z)/2);
   if (i == 8) rmSetAreaLocation(connectIslandID, (p8x + e4x)/2, (p8z + e4z)/2);
  }
   rmBuildAllAreas();

// Place bonus islands
   if(useBonusIslandsFlag == true)
 {
   for(i=1; <= islandCount)
  {
   int bonusIslandID=rmCreateArea("bonus island"+i);
   rmSetAreaSize(bonusIslandID, rmAreaTilesToFraction(0.75*bonusIslandSize),  rmAreaTilesToFraction(bonusIslandSize));
   rmSetAreaMinBlobs(bonusIslandID, 10); rmSetAreaMaxBlobs(bonusIslandID, 15);
   rmSetAreaMinBlobDistance(bonusIslandID, 8.0); rmSetAreaMaxBlobDistance(bonusIslandID, 10.0);
   rmSetAreaCoherence(bonusIslandID, 0.45); // was .55
   rmSetAreaBaseHeight(bonusIslandID, 2.5);
   rmSetAreaSmoothDistance(bonusIslandID, 20);
   rmSetAreaMix(bonusIslandID, terrainMix);
   rmAddAreaConstraint(bonusIslandID, avoidMainLand);
   rmAddAreaConstraint(bonusIslandID, avoidLand);
   rmAddAreaConstraint(bonusIslandID, avoidFlag);
   rmSetAreaElevationType(bonusIslandID, cElevTurbulence);
   rmSetAreaElevationVariation(bonusIslandID, 4.0);
   rmSetAreaElevationMinFrequency(bonusIslandID, 0.09);
   rmSetAreaElevationOctaves(bonusIslandID, 3);
   rmSetAreaElevationPersistence(bonusIslandID, 0.2);
   rmSetAreaElevationNoiseBias(bonusIslandID, 1);
   rmSetAreaWarnFailure(bonusIslandID, false);
   rmBuildArea(bonusIslandID);
  }
 }
// Place dirt around town centers.
   if(rmGetNomadStart() == false)
 {
   for(i=1; <= players)
  {
   int playerDirtID=rmCreateArea("player dirt"+i);
   rmSetAreaSize(playerDirtID, rmAreaTilesToFraction(120),  rmAreaTilesToFraction(120));
   rmSetAreaMinBlobs(playerDirtID, 1); rmSetAreaMaxBlobs(playerDirtID, 1);
   rmSetAreaCoherence(playerDirtID, 0.95);
   rmSetAreaBaseHeight(playerDirtID, 2.0);
   rmSetAreaSmoothDistance(playerDirtID, 3);
   rmSetAreaMix(playerDirtID, TCDirt);
   rmSetAreaElevationType(playerDirtID, cElevTurbulence);
   rmSetAreaElevationVariation(playerDirtID, 4.0);
   rmSetAreaElevationMinFrequency(playerDirtID, 0.09);
   rmSetAreaElevationOctaves(playerDirtID, 3);
   rmSetAreaElevationPersistence(playerDirtID, 0.2);
   rmSetAreaElevationNoiseBias(playerDirtID, 1);
   rmSetAreaWarnFailure(playerDirtID, false);
   if (i == 1) rmSetAreaLocation(playerDirtID, p1x, p1z);
   if (i == 2) rmSetAreaLocation(playerDirtID, p2x, p2z);
   if (i == 3) rmSetAreaLocation(playerDirtID, p3x, p3z);
   if (i == 4) rmSetAreaLocation(playerDirtID, p4x, p4z);
   if (i == 5) rmSetAreaLocation(playerDirtID, p5x, p5z);
   if (i == 6) rmSetAreaLocation(playerDirtID, p6x, p6z);
   if (i == 7) rmSetAreaLocation(playerDirtID, p7x, p7z);
   if (i == 8) rmSetAreaLocation(playerDirtID, p8x, p8z);
  }
 }
   rmBuildAllAreas();

// Starting TCs and units

 /* I5.0 Position players */  rmSetStatusText("",0.5);
   if (rmGetNomadStart() == false)
 {
 		
   int startingUnits = rmCreateStartingUnitsObjectDef(5.0);
   rmSetObjectDefMinDistance(startingUnits, 5.0);
   rmSetObjectDefMaxDistance(startingUnits, 10.0);
   rmAddObjectDefConstraint(startingUnits, avoidAll);

   int startingTCID= rmCreateObjectDef("startingTC");
   rmAddObjectDefConstraint(startingTCID, avoidAll);                
   rmAddObjectDefItem(startingTCID, "TownCenter", 1, 0.0); 

   for(i=1; <= players)
   {	
   if(i == 1) { rmPlaceObjectDefAtLoc(startingTCID, 1, p1x, p1z); rmPlaceObjectDefAtLoc(startingUnits, 1, p1x, p1z); }
   if(i == 2) { rmPlaceObjectDefAtLoc(startingTCID, 2, p2x, p2z); rmPlaceObjectDefAtLoc(startingUnits, 2, p2x, p2z); }
   if(i == 3) { rmPlaceObjectDefAtLoc(startingTCID, 3, p3x, p3z); rmPlaceObjectDefAtLoc(startingUnits, 3, p3x, p3z); }
   if(i == 4) { rmPlaceObjectDefAtLoc(startingTCID, 4, p4x, p4z); rmPlaceObjectDefAtLoc(startingUnits, 4, p4x, p4z); }
   if(i == 5) { rmPlaceObjectDefAtLoc(startingTCID, 5, p5x, p5z); rmPlaceObjectDefAtLoc(startingUnits, 5, p5x, p5z); }
   if(i == 6) { rmPlaceObjectDefAtLoc(startingTCID, 6, p6x, p6z); rmPlaceObjectDefAtLoc(startingUnits, 6, p6x, p6z); }
   if(i == 7) { rmPlaceObjectDefAtLoc(startingTCID, 7, p7x, p7z); rmPlaceObjectDefAtLoc(startingUnits, 7, p7x, p7z); }
   if(i == 8) { rmPlaceObjectDefAtLoc(startingTCID, 8, p8x, p8z); rmPlaceObjectDefAtLoc(startingUnits, 8, p8x, p8z); }
   }
 } 
// I5.1 Place explorer or covered wagon for Nomad start.
   if (rmGetNomadStart())
 {
   rmPlaceObjectDefAtLoc(explorerID, 1, p1x, p1z); 
   if(ident2 == 1) rmPlaceObjectDefAtLoc(explorerID, 2, p2x, p2z);
   if(ident2 == 0)rmPlaceObjectDefAtLoc(coveredWagonID, 2, p2x, p2z);
   if(players > 2 && ident3 == 1) rmPlaceObjectDefAtLoc(explorerID, 3, p3x, p3z);
   if(players > 2 && ident3 == 0) rmPlaceObjectDefAtLoc(coveredWagonID, 3, p3x, p3z);
   if(players > 3 && ident4 == 1) rmPlaceObjectDefAtLoc(explorerID, 4, p4x, p4z);
   if(players > 3 && ident4 == 0) rmPlaceObjectDefAtLoc(coveredWagonID, 4, p4x, p4z);
   if(players > 4 && ident5 == 1) rmPlaceObjectDefAtLoc(explorerID, 5, p5x, p5z);
   if(players > 4 && ident5 == 0) rmPlaceObjectDefAtLoc(coveredWagonID, 5, p5x, p5z);
   if(players > 5 && ident6 == 1) rmPlaceObjectDefAtLoc(explorerID, 6, p6x, p6z);
   if(players > 5 && ident6 == 0) rmPlaceObjectDefAtLoc(coveredWagonID, 6, p6x, p6z);
   if(players > 6 && ident7 == 1) rmPlaceObjectDefAtLoc(explorerID, 7, p7x, p7z);
   if(players > 6 && ident7 == 0) rmPlaceObjectDefAtLoc(coveredWagonID, 7, p7x, p7z);
   if(players > 7 && ident8 == 1) rmPlaceObjectDefAtLoc(explorerID, 8, p8x, p8z);
   if(players > 7 && ident8 == 0) rmPlaceObjectDefAtLoc(coveredWagonID, 8, p8x, p8z);
 }
// I5.2 Place Water Flags
   int waterFlagID=-1;
   for(i=1; <= players)
   {
   rmClearClosestPointConstraints();
   waterFlagID=rmCreateObjectDef("HC water flag "+i);
   rmAddObjectDefItem(waterFlagID, "HomeCityWaterSpawnFlag", 1, 0.0);
   if(i < 5 || (i == 5 && players != 5) ||( i < 7 && players != 5)) rmAddClosestPointConstraint(flagEdgeConstraint);
   rmAddClosestPointConstraint(avoidFlag);
   rmAddClosestPointConstraint(flagLand);
   if(rmGetNomadStart() == false) vector TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(startingTCID, i));
   if(rmGetNomadStart())
 {
   if(i == 1) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(explorerID, i));
   if(i == 2 && ident2 == 0) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(coveredWagonID, i));
   if(i == 2 && ident2 == 1) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(explorerID, i));
   if(i == 3 && ident3 == 0) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(coveredWagonID, i));
   if(i == 3 && ident3 == 1) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(explorerID, i));
   if(i == 4 && ident4 == 0) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(coveredWagonID, i));
   if(i == 4 && ident4 == 1) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(explorerID, i));
   if(i == 5 && ident5 == 0) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(coveredWagonID, i));
   if(i == 5 && ident5 == 1) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(explorerID, i));
   if(i == 6 && ident6 == 0) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(coveredWagonID, i));
   if(i == 6 && ident6 == 1) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(explorerID, i));
   if(i == 7 && ident7 == 0) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(coveredWagonID, i));
   if(i == 7 && ident7 == 1) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(explorerID, i));
   if(i == 8 && ident8 == 0) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(coveredWagonID, i));
   if(i == 8 && ident8 == 1) TCLocation = rmGetUnitPosition(rmGetUnitPlacedOfPlayer(explorerID, i));
 }
   vector closestPoint = rmFindClosestPointVector(TCLocation, rmXFractionToMeters(1.0));
   rmPlaceObjectDefAtLoc(waterFlagID, i, rmXMetersToFraction(xsVectorGetX(closestPoint)), rmZMetersToFraction(xsVectorGetZ(closestPoint)));
   if(i == 1)  vector waterFlag1 = closestPoint; if(i == 2)  vector waterFlag2 = closestPoint;
   if(i == 3)  vector waterFlag3 = closestPoint; if(i == 4)  vector waterFlag4 = closestPoint;
   if(i == 5)  vector waterFlag5 = closestPoint; if(i == 6)  vector waterFlag6 = closestPoint;
   if(i == 7)  vector waterFlag7 = closestPoint; if(i == 8)  vector waterFlag8 = closestPoint;
   rmClearClosestPointConstraints();
   }
// I5.3 Landing party placement
// Place player 1 landing party and caravel and any others
   if (rmGetNomadStart()) 
 {
// Landing party for player 1
   rmPlaceObjectDefAtLoc(settlerID, 1, p1x, p1z);
   rmPlaceObjectDefAtLoc(mercenaryID, 1, p1x, p1z); rmPlaceObjectDefAtLoc(surgeonID, 1, p1x, p1z); 
   rmPlaceObjectDefAtLoc(caravelID, 1, rmXMetersToFraction(xsVectorGetX(waterFlag1)), rmZMetersToFraction(xsVectorGetZ(waterFlag1)));
// Landing party for player 2
   if(ident2 == 1) { 
   rmPlaceObjectDefAtLoc(settlerID, 2, p2x, p2z); rmPlaceObjectDefAtLoc(mercenaryID, 2, p2x, p2z); rmPlaceObjectDefAtLoc(surgeonID, 2, p2x, p2z); 
   rmPlaceObjectDefAtLoc(caravelID, 2, rmXMetersToFraction(xsVectorGetX(waterFlag2)), rmZMetersToFraction(xsVectorGetZ(waterFlag2))); }
// Landing party for player 3
   if(players > 2 && ident3 == 1) { rmPlaceObjectDefAtLoc(settlerID, 3, p3x, p3z);
   rmPlaceObjectDefAtLoc(mercenaryID, 3, p3x, p3z); rmPlaceObjectDefAtLoc(surgeonID, 3, p3x, p3z);
   rmPlaceObjectDefAtLoc(caravelID, 3, rmXMetersToFraction(xsVectorGetX(waterFlag3)), rmZMetersToFraction(xsVectorGetZ(waterFlag3))); }
// Landing party for player 4
   if(players > 3 && ident4 == 1) { rmPlaceObjectDefAtLoc(settlerID, 4, p4x, p4z);
   rmPlaceObjectDefAtLoc(mercenaryID, 4, p4x, p4z); rmPlaceObjectDefAtLoc(surgeonID, 4, p4x, p4z); 
   rmPlaceObjectDefAtLoc(caravelID, 4, rmXMetersToFraction(xsVectorGetX(waterFlag4)), rmZMetersToFraction(xsVectorGetZ(waterFlag4))); }
// Landing party for player 5
   if(players > 4 && ident5 == 1) { rmPlaceObjectDefAtLoc(settlerID, 5, p5x, p5z);
   rmPlaceObjectDefAtLoc(mercenaryID, 5, p5x, p5z); rmPlaceObjectDefAtLoc(surgeonID, 5, p5x, p5z); 
   rmPlaceObjectDefAtLoc(caravelID, 5, rmXMetersToFraction(xsVectorGetX(waterFlag5)), rmZMetersToFraction(xsVectorGetZ(waterFlag5))); }
// Landing party for player 6
   if(players > 5 && ident6 == 1) { rmPlaceObjectDefAtLoc(settlerID, 6, p6x, p6z);
   rmPlaceObjectDefAtLoc(mercenaryID, 6, p6x, p6z); rmPlaceObjectDefAtLoc(surgeonID, 6, p6x, p6z); 
   rmPlaceObjectDefAtLoc(caravelID, 6, rmXMetersToFraction(xsVectorGetX(waterFlag6)), rmZMetersToFraction(xsVectorGetZ(waterFlag6))); }
// Landing party for player 7
   if(players > 6 && ident7 == 1) { rmPlaceObjectDefAtLoc(settlerID, 7, p7x, p7z);
   rmPlaceObjectDefAtLoc(mercenaryID, 7, p7x, p7z); rmPlaceObjectDefAtLoc(surgeonID, 7, p7x, p7z); 
   rmPlaceObjectDefAtLoc(caravelID, 7, rmXMetersToFraction(xsVectorGetX(waterFlag7)), rmZMetersToFraction(xsVectorGetZ(waterFlag7))); }
// Landing party for player 8
   if(players > 7 && ident8 == 1) { rmPlaceObjectDefAtLoc(settlerID, 8, p8x, p8z);
   rmPlaceObjectDefAtLoc(mercenaryID, 8, p8x, p8z); rmPlaceObjectDefAtLoc(surgeonID, 8, p8x, p8z); 
   rmPlaceObjectDefAtLoc(caravelID, 8, rmXMetersToFraction(xsVectorGetX(waterFlag8)), rmZMetersToFraction(xsVectorGetZ(waterFlag8))); }
  }
/* I6.0 Place Objects*/  rmSetStatusText("",0.6);

/* I6.1 Placement order. Pirate ships and surprise wagon are put first because the item ID seems to work better.

   Pirate ships, surprise wagon, Trade routes, natives, mines, huntables, herdable, trees, berries, nuggets, random trees, whales, forest, fish,
   rocks, ducks, water plants, shipwrecks, forests, special item, crates, bison carcass, and BFG.

   I6.2 Place pirate ships */
   if(usePiratesFlag == true)
 {
// Place pirate ship one
   rmPlaceObjectDefAtLoc(pirate1ID, 0, e1x, e1z);
   int pirate1Select = rmGetUnitPlaced(pirate1ID, 0);
// Place pirate ship two
   if(players > 2) 
  {
   if(players > 3)  rmPlaceObjectDefAtLoc(pirate2ID, 0, e2x, e2z);
   if(players == 3) rmPlaceObjectDefAtLoc(pirate2ID, 0, p3x, p3z);
   int pirate2Select = rmGetUnitPlaced(pirate2ID, 0);
  }
// Place pirate ship three
   if(players > 4) 
  {
   if(players > 5)  rmPlaceObjectDefAtLoc(pirate3ID, 0, e3x, e3z);
   if(players == 5) rmPlaceObjectDefAtLoc(pirate3ID, 0, 0.5, 0.5);
   int pirate3Select = rmGetUnitPlaced(pirate3ID, 0);
  }
// Place pirate ship four
   if(players > 6) 
  {
   if(players > 7)  rmPlaceObjectDefAtLoc(pirate4ID, 0, e4x, e4z);
   if(players == 7) rmPlaceObjectDefAtLoc(pirate4ID, 0, 0.5, 0.5);
   int pirate4Select = rmGetUnitPlaced(pirate4ID, 0);
  }
 }
// I6.3 Place surprise wagon(Fort, Outpost, Covered, or Factory)
   if(useSurpriseFlag == true)
 {
   rmPlaceObjectDefAtLoc(surpriseID, 0, 0.5, 0.5, 1);
   int surpriseSelect = rmGetUnitPlaced(surpriseID, 0);
 }
/* I6.4 Place trade routes */  rmSetStatusText("",0.7);
   if(useTradeRoutesFlag == true)
 {
   int socketID=rmCreateObjectDef("sockets for Trade Posts");
   rmAddObjectDefItem(socketID, "SocketTradeRoute", 1, 0.0); rmSetObjectDefAllowOverlap(socketID, true);
   rmSetObjectDefMinDistance(socketID, 0.0); rmSetObjectDefMaxDistance(socketID, 8.0);
   rmAddObjectDefConstraint(socketID, avoidWater);

   int tradeRoute1ID = rmCreateTradeRoute();
   rmAddTradeRouteWaypoint(tradeRoute1ID, ((7.0*p1x)+e1x)/8.0, ((7.0*p1z)+e1z)/8.0);
   rmAddRandomTradeRouteWaypoints(tradeRoute1ID, e1x, e1z, 8, 10);
   rmAddRandomTradeRouteWaypoints(tradeRoute1ID, ((7.0*p2x)+e1x)/8.0, ((7.0*p2z)+e1z)/8.0, 8, 10);

   bool placedTradeRoute1 = rmBuildTradeRoute(tradeRoute1ID, "dirt");
   if(placedTradeRoute1 == false) rmEchoError("Failed to place trade route one");

// add the meeting sockets along the trade route.
   rmSetObjectDefTradeRouteID(socketID, tradeRoute1ID);
   vector socketLoc = rmGetTradeRouteWayPoint(tradeRoute1ID, 0.05); rmPlaceObjectDefAtPoint(socketID, 0, socketLoc);
   socketLoc = rmGetTradeRouteWayPoint(tradeRoute1ID, 0.5); rmPlaceObjectDefAtPoint(socketID, 0, socketLoc);
   socketLoc = rmGetTradeRouteWayPoint(tradeRoute1ID, 0.95); rmPlaceObjectDefAtPoint(socketID, 0, socketLoc);

   if(players > 3)
  {
   int tradeRoute2ID = rmCreateTradeRoute();
   rmAddTradeRouteWaypoint(tradeRoute2ID, ((7.0*p3x)+e2x)/8.0, ((7.0*p3z)+e2x)/8.0);
   rmAddRandomTradeRouteWaypoints(tradeRoute2ID, e2x, e2z, 8, 10);
   rmAddRandomTradeRouteWaypoints(tradeRoute2ID, ((7.0*p4x)+e2x)/8.0, ((7.0*p4z)+e2x)/8.0, 8, 10);
		
   bool placedTradeRoute2 = rmBuildTradeRoute(tradeRoute2ID, "dirt");
   if(placedTradeRoute2 == false) rmEchoError("Failed to place trade route one");

// add the meeting sockets along the trade route.
   rmSetObjectDefTradeRouteID(socketID, tradeRoute2ID);
   socketLoc = rmGetTradeRouteWayPoint(tradeRoute2ID, 0.05); rmPlaceObjectDefAtPoint(socketID, 0, socketLoc);
   socketLoc = rmGetTradeRouteWayPoint(tradeRoute2ID, 0.5); rmPlaceObjectDefAtPoint(socketID, 0, socketLoc);
   socketLoc = rmGetTradeRouteWayPoint(tradeRoute2ID, 0.95); rmPlaceObjectDefAtPoint(socketID, 0, socketLoc);
  }
   if(players > 5)
  {
   int tradeRoute3ID = rmCreateTradeRoute();
   rmAddTradeRouteWaypoint(tradeRoute3ID, ((7.0*p5x)+e3x)/8.0, ((7.0*p5z)+e3x)/8.0);
   rmAddRandomTradeRouteWaypoints(tradeRoute3ID, e3x, e3z, 8, 10);
   rmAddRandomTradeRouteWaypoints(tradeRoute3ID, ((7.0*p6x)+e3x)/8.0, ((7.0*p6z)+e3x)/8.0, 8, 10);
		
   bool placedTradeRoute3 = rmBuildTradeRoute(tradeRoute3ID, "dirt");
   if(placedTradeRoute3 == false) rmEchoError("Failed to place trade route one");

// add the meeting sockets along the trade route.
   rmSetObjectDefTradeRouteID(socketID, tradeRoute3ID);
   socketLoc = rmGetTradeRouteWayPoint(tradeRoute3ID, 0.05); rmPlaceObjectDefAtPoint(socketID, 0, socketLoc);
   socketLoc = rmGetTradeRouteWayPoint(tradeRoute3ID, 0.5); rmPlaceObjectDefAtPoint(socketID, 0, socketLoc);
   socketLoc = rmGetTradeRouteWayPoint(tradeRoute3ID, 0.95); rmPlaceObjectDefAtPoint(socketID, 0, socketLoc);
  }
   if(players > 7)
  {
   int tradeRoute4ID = rmCreateTradeRoute();
   rmAddTradeRouteWaypoint(tradeRoute4ID, ((7.0*p7x)+e4x)/8.0, ((7.0*p7z)+e4x)/8.0);
   rmAddRandomTradeRouteWaypoints(tradeRoute4ID, e4x, e4z, 8, 10);
   rmAddRandomTradeRouteWaypoints(tradeRoute4ID, ((7.0*p8x)+e4x)/8.0, ((7.0*p8z)+e4x)/8.0, 8, 10);
		
   bool placedTradeRoute4 = rmBuildTradeRoute(tradeRoute4ID, "dirt");
   if(placedTradeRoute4 == false) rmEchoError("Failed to place trade route one");

// add the meeting sockets along the trade route.
   rmSetObjectDefTradeRouteID(socketID, tradeRoute4ID);
   socketLoc = rmGetTradeRouteWayPoint(tradeRoute4ID, 0.05); rmPlaceObjectDefAtPoint(socketID, 0, socketLoc);
   socketLoc = rmGetTradeRouteWayPoint(tradeRoute4ID, 0.5); rmPlaceObjectDefAtPoint(socketID, 0, socketLoc);
   socketLoc = rmGetTradeRouteWayPoint(tradeRoute4ID, 0.95); rmPlaceObjectDefAtPoint(socketID, 0, socketLoc);
  }
 }
/* I6.5 Place Natives */  rmSetStatusText("",0.8);

   if(useNativesFlag == true)
{
   if(nativeSet == 1)
{
   if (subCiv0 == rmGetCivID("aztecs"))
 {  
   int aztecsVillage1ID = -1;
   int aztecsVillage1Type = rmRandInt(1,3);
   aztecsVillage1ID = rmCreateGrouping("aztec 1 city", "native aztec village "+aztecsVillage1Type);
   rmSetGroupingMinDistance(aztecsVillage1ID, 0.0); rmSetGroupingMaxDistance(aztecsVillage1ID, 50.0);
   rmAddGroupingToClass(aztecsVillage1ID, rmClassID("natives"));
   rmAddGroupingConstraint(aztecsVillage1ID, avoidTradeRoute); rmAddGroupingConstraint(aztecsVillage1ID, avoidTC30);
   rmPlaceGroupingAtLoc(aztecsVillage1ID, 0, e1x, e1z);
 }
   if(players > 2)
 {
   if (subCiv1 == rmGetCivID("caribs"))
 {  
   int caribsVillage1ID = -1;
   int caribsVillage1Type = rmRandInt(1,3);
   caribsVillage1ID = rmCreateGrouping("caribs 1 city", "native carib village "+caribsVillage1Type);
   rmSetGroupingMinDistance(caribsVillage1ID, 0.0); rmSetGroupingMaxDistance(caribsVillage1ID, 50.0);
   rmAddGroupingToClass(caribsVillage1ID, rmClassID("natives"));
   rmAddGroupingConstraint(caribsVillage1ID, avoidTradeRoute); rmAddGroupingConstraint(caribsVillage1ID, avoidTC30);
   if(players != 3)rmPlaceGroupingAtLoc(caribsVillage1ID, 0, e2x, e2z);
   if(players == 3)rmPlaceGroupingAtLoc(caribsVillage1ID, 0, p3x, p3z);
 }
 }
   if(players > 4)
 {
   if (subCiv2 == rmGetCivID("nootka"))
 {  
   int nootkaVillage1ID = -1;
   int nootkaVillage1Type = rmRandInt(1,3);
   nootkaVillage1ID = rmCreateGrouping("nootka 1 city", "native nootka village "+nootkaVillage1Type);
   rmSetGroupingMinDistance(nootkaVillage1ID, 0.0); rmSetGroupingMaxDistance(nootkaVillage1ID, 50.0);
   rmAddGroupingToClass(nootkaVillage1ID, rmClassID("natives"));
   rmAddGroupingConstraint(nootkaVillage1ID, avoidTradeRoute); rmAddGroupingConstraint(nootkaVillage1ID, avoidTC30);
   if(players != 5) rmPlaceGroupingAtLoc(nootkaVillage1ID, 0, e3x, e3z);
   if(players == 5) rmPlaceGroupingAtLoc(nootkaVillage1ID, 0, 0.5, 0.5);
 }
 }
   if(players > 6)
 {
   if (subCiv3 == rmGetCivID("tupi"))
 {  
   int tupiVillage1ID = -1;
   int tupiVillage1Type = rmRandInt(1,3);
   tupiVillage1ID = rmCreateGrouping("tupi 1 city", "native tupi village "+tupiVillage1Type);
   rmSetGroupingMinDistance(tupiVillage1ID, 0.0); rmSetGroupingMaxDistance(tupiVillage1ID, 50.0);
   rmAddGroupingToClass(tupiVillage1ID, rmClassID("natives"));
   rmAddGroupingConstraint(tupiVillage1ID, avoidTradeRoute); rmAddGroupingConstraint(tupiVillage1ID, avoidTC30);
   if(players != 7) rmPlaceGroupingAtLoc(tupiVillage1ID, 0, e4x, e4z);
   if(players == 7) rmPlaceGroupingAtLoc(tupiVillage1ID, 0, 0.5, 0.5);
 }
 }
}
   if(nativeSet == 2)
{
   if (subCiv0 == rmGetCivID("caribs"))
 {  
   int caribsVillage2ID = -1;
   int caribsVillage2Type = rmRandInt(1,3);
   caribsVillage2ID = rmCreateGrouping("carib 2 city", "native carib village "+caribsVillage2Type);
   rmSetGroupingMinDistance(caribsVillage2ID, 0.0); rmSetGroupingMaxDistance(caribsVillage2ID, 50.0);
   rmAddGroupingToClass(caribsVillage2ID, rmClassID("natives"));
   rmAddGroupingConstraint(caribsVillage2ID, avoidTradeRoute); rmAddGroupingConstraint(caribsVillage2ID, avoidTC30);
   rmPlaceGroupingAtLoc(caribsVillage2ID, 0, e1x, e1z);
 }
   if(players > 2)
 {
   if (subCiv1 == rmGetCivID("nootka"))
 {  
   int nootkaVillage2ID = -1;
   int nootkaVillage2Type = rmRandInt(1,3);
   nootkaVillage2ID = rmCreateGrouping("nootka 2 city", "native nootka village "+nootkaVillage2Type);
   rmSetGroupingMinDistance(nootkaVillage2ID, 0.0); rmSetGroupingMaxDistance(nootkaVillage2ID, 50.0);
   rmAddGroupingToClass(nootkaVillage2ID, rmClassID("natives"));
   rmAddGroupingConstraint(nootkaVillage2ID, avoidTradeRoute); rmAddGroupingConstraint(nootkaVillage2ID, avoidTC30);
   if(players != 3) rmPlaceGroupingAtLoc(nootkaVillage2ID, 0, e2x, e2z);
   if(players == 3) rmPlaceGroupingAtLoc(nootkaVillage2ID, 0, p3x, p3z);
 }
 }
   if(players > 4)
 {
   if (subCiv2 == rmGetCivID("tupi"))
 {  
   int tupiVillage2ID = -1;
   int tupiVillage2Type = rmRandInt(1,3);
   tupiVillage2ID = rmCreateGrouping("tupi 2 city", "native tupi village "+tupiVillage2Type);
   rmSetGroupingMinDistance(tupiVillage2ID, 0.0); rmSetGroupingMaxDistance(tupiVillage2ID, 50.0);
   rmAddGroupingToClass(tupiVillage2ID, rmClassID("natives"));
   rmAddGroupingConstraint(tupiVillage2ID, avoidTradeRoute); rmAddGroupingConstraint(tupiVillage2ID, avoidTC30);
   if(players != 5) rmPlaceGroupingAtLoc(tupiVillage2ID, 0, e3x, e3z);
   if(players == 5) rmPlaceGroupingAtLoc(tupiVillage2ID, 0, 0.5, 0.5);
 }
 }
   if(players > 6)
 {
   if (subCiv3 == rmGetCivID("aztecs"))
 {  
   int aztecsVillage2ID = -1;
   int aztecsVillage2Type = rmRandInt(1,3);
   aztecsVillage2ID = rmCreateGrouping("aztecs 2 city", "native aztec village "+aztecsVillage2Type);
   rmSetGroupingMinDistance(aztecsVillage2ID, 0.0); rmSetGroupingMaxDistance(aztecsVillage2ID, 50.0);
   rmAddGroupingToClass(aztecsVillage2ID, rmClassID("natives"));
   rmAddGroupingConstraint(aztecsVillage2ID, avoidTradeRoute); rmAddGroupingConstraint(aztecsVillage2ID, avoidTC30);
   if(players != 7) rmPlaceGroupingAtLoc(aztecsVillage2ID, 0, e4x, e4z);
   if(players == 7) rmPlaceGroupingAtLoc(aztecsVillage2ID, 0, 0.5, 0.5);
 }
 }
}
   if(nativeSet == 3)
{
   if (subCiv0 == rmGetCivID("nootka"))
 {  
   int nootkaVillage3ID = -1;
   int nootkaVillage3Type = rmRandInt(1,3);
   nootkaVillage3ID = rmCreateGrouping("nootka 3 city", "native nootka village "+nootkaVillage3Type);
   rmSetGroupingMinDistance(nootkaVillage3ID, 0.0); rmSetGroupingMaxDistance(nootkaVillage3ID, 50.0);
   rmAddGroupingToClass(nootkaVillage3ID, rmClassID("natives"));
   rmAddGroupingConstraint(nootkaVillage3ID, avoidTradeRoute); rmAddGroupingConstraint(nootkaVillage3ID, avoidTC30);
   rmPlaceGroupingAtLoc(nootkaVillage3ID, 0, e1x, e1z);
 }
   if(players > 2)
 {
   if (subCiv1 == rmGetCivID("tupi"))
 {  
   int tupiVillage3ID = -1;
   int tupiVillage3Type = rmRandInt(1,3);
   tupiVillage3ID = rmCreateGrouping("tupi 3 city", "native tupi village "+tupiVillage3Type);
   rmSetGroupingMinDistance(tupiVillage3ID, 0.0); rmSetGroupingMaxDistance(tupiVillage3ID, 50.0);
   rmAddGroupingToClass(tupiVillage3ID, rmClassID("natives"));
   rmAddGroupingConstraint(tupiVillage3ID, avoidTradeRoute); rmAddGroupingConstraint(tupiVillage3ID, avoidTC30);
   if(players != 3) rmPlaceGroupingAtLoc(tupiVillage3ID, 0, e2x, e2z);
   if(players == 3) rmPlaceGroupingAtLoc(tupiVillage3ID, 0, p3x, p3z);
 }
 }
   if(players > 4)
 {
   if (subCiv2 == rmGetCivID("aztecs"))
 {  
   int aztecsVillage3ID = -1;
   int aztecsVillage3Type = rmRandInt(1,3);
   aztecsVillage3ID = rmCreateGrouping("aztecs 3 city", "native aztec village "+aztecsVillage3Type);
   rmSetGroupingMinDistance(aztecsVillage3ID, 0.0); rmSetGroupingMaxDistance(aztecsVillage3ID, 50.0);
   rmAddGroupingToClass(aztecsVillage3ID, rmClassID("natives"));
   rmAddGroupingConstraint(aztecsVillage3ID, avoidTradeRoute); rmAddGroupingConstraint(aztecsVillage3ID, avoidTC30);
   if(players != 5) rmPlaceGroupingAtLoc(aztecsVillage3ID, 0, e3x, e3z);
   if(players == 5) rmPlaceGroupingAtLoc(aztecsVillage3ID, 0, 0.5, 0.5);
 }
 }
   if(players > 6)
 {
   if (subCiv3 == rmGetCivID("caribs"))
 {  
   int caribsVillage3ID = -1;
   int caribsVillage3Type = rmRandInt(1,3);
   caribsVillage3ID = rmCreateGrouping("caribs 3 city", "native carib village "+caribsVillage3Type);
   rmSetGroupingMinDistance(caribsVillage3ID, 0.0); rmSetGroupingMaxDistance(caribsVillage3ID, 50.0);
   rmAddGroupingToClass(caribsVillage3ID, rmClassID("natives"));
   rmAddGroupingConstraint(caribsVillage3ID, avoidTradeRoute); rmAddGroupingConstraint(caribsVillage3ID, avoidTC30);
   if(players != 7) rmPlaceGroupingAtLoc(caribsVillage3ID, 0, e4x, e4z);
   if(players == 7) rmPlaceGroupingAtLoc(caribsVillage3ID, 0, 0.5, 0.5);
 }
 }
}
   if(nativeSet == 4)
{
   if (subCiv0 == rmGetCivID("tupi"))
 {  
   int tupiVillage4ID = -1;
   int tupiVillage4Type = rmRandInt(1,3);
   tupiVillage4ID = rmCreateGrouping("tupi 4 city", "native tupi village "+tupiVillage4Type);
   rmSetGroupingMinDistance(tupiVillage4ID, 0.0); rmSetGroupingMaxDistance(tupiVillage4ID, 50.0);
   rmAddGroupingToClass(tupiVillage4ID, rmClassID("natives"));
   rmAddGroupingConstraint(tupiVillage4ID, avoidTradeRoute); rmAddGroupingConstraint(tupiVillage4ID, avoidTC30);
   rmPlaceGroupingAtLoc(tupiVillage4ID, 0, e1x, e1z);
 }
   if(players > 2)
 {
   if (subCiv1 == rmGetCivID("aztecs"))
 {  
   int aztecsVillage4ID = -1;
   int aztecsVillage4Type = rmRandInt(1,3);
   aztecsVillage4ID = rmCreateGrouping("aztecs 4 city", "native aztec village "+aztecsVillage4Type);
   rmSetGroupingMinDistance(aztecsVillage4ID, 0.0); rmSetGroupingMaxDistance(aztecsVillage4ID, 50.0);
   rmAddGroupingToClass(aztecsVillage4ID, rmClassID("natives"));
   rmAddGroupingConstraint(aztecsVillage4ID, avoidTradeRoute); rmAddGroupingConstraint(aztecsVillage4ID, avoidTC30);
   if(players != 3) rmPlaceGroupingAtLoc(aztecsVillage4ID, 0, e2x, e2z);
   if(players == 3) rmPlaceGroupingAtLoc(aztecsVillage4ID, 0, p3x, p3z);
 }
 }
   if(players > 4)
 {
   if (subCiv2 == rmGetCivID("caribs"))
 {  
   int caribsVillage4ID = -1;
   int caribsVillage4Type = rmRandInt(1,3);
   caribsVillage4ID = rmCreateGrouping("caribs 4 city", "native carib village "+caribsVillage4Type);
   rmSetGroupingMinDistance(caribsVillage4ID, 0.0); rmSetGroupingMaxDistance(caribsVillage4ID, 50.0);
   rmAddGroupingToClass(caribsVillage4ID, rmClassID("natives"));
   rmAddGroupingConstraint(caribsVillage4ID, avoidTradeRoute); rmAddGroupingConstraint(caribsVillage4ID, avoidTC30); 
   if(players != 5) rmPlaceGroupingAtLoc(caribsVillage4ID, 0, e3x, e3z);
   if(players == 5) rmPlaceGroupingAtLoc(caribsVillage4ID, 0, 0.5, 0.5);
 }
 }
   if(players > 6)
 {
   if (subCiv3 == rmGetCivID("nootka"))
 {  
   int nootkaVillage4ID = -1;
   int nootkaVillage4Type = rmRandInt(1,3);
   nootkaVillage4ID = rmCreateGrouping("nootka 4 city", "native nootka village "+nootkaVillage4Type);
   rmSetGroupingMinDistance(nootkaVillage4ID, 0.0); rmSetGroupingMaxDistance(nootkaVillage4ID, 50.0);
   rmAddGroupingToClass(nootkaVillage4ID, rmClassID("natives"));
   rmAddGroupingConstraint(nootkaVillage4ID, avoidTradeRoute); rmAddGroupingConstraint(nootkaVillage4ID, avoidTC30);
   if(players != 7) rmPlaceGroupingAtLoc(nootkaVillage4ID, 0, e4x, e4z);
   if(players == 7) rmPlaceGroupingAtLoc(nootkaVillage4ID, 0, 0.5, 0.5);
 }
 }
}
}
// I6.6 Place mines 

// Player Mines
   rmPlaceObjectDefAtLoc(silverID, 0, p1x, p1z, 2);
   rmPlaceObjectDefAtLoc(silverID, 0, p2x, p2z, 2);
   if(players > 2) rmPlaceObjectDefAtLoc(silverID, 0, p3x, p3z, 2);
   if(players > 3) rmPlaceObjectDefAtLoc(silverID, 0, p4x, p4z, 2);
   if(players > 4) rmPlaceObjectDefAtLoc(silverID, 0, p5x, p5z, 2);
   if(players > 5) rmPlaceObjectDefAtLoc(silverID, 0, p6x, p6z, 2);
   if(players > 6) rmPlaceObjectDefAtLoc(silverID, 0, p7x, p7z, 2);
   if(players > 7) rmPlaceObjectDefAtLoc(silverID, 0, p8x, p8z, 2);

// Other mines
   int minePick = rmRandInt(1,4);
   int mineCount = 1; if(minePick == 2 || minePick == 4) mineCount = 2;
   if(minePick == 1 || minePick == 2)
{
// Elbow islands with silver mines
   rmPlaceObjectDefAtLoc(silverID, 0, e1x, e1z, mineCount);
   if(players > 3) rmPlaceObjectDefAtLoc(silverID, 0, e2x, e2z, mineCount);
   if(players > 5) rmPlaceObjectDefAtLoc(silverID, 0, e3x, e3z, mineCount);
   if(players > 7) rmPlaceObjectDefAtLoc(silverID, 0, e4x, e4z, mineCount);
// Connection island with silver mines
   rmPlaceObjectDefAtLoc(silverID, 0, (p1x+e1x)/2.0, (p1z+e1z)/2.0, mineCount);
   rmPlaceObjectDefAtLoc(silverID, 0, (p2x+e1x)/2.0, (p2z+e1z)/2.0, mineCount);
   if(players > 3)
 { rmPlaceObjectDefAtLoc(silverID, 0, (p3x+e2x)/2.0, (p3z+e2z)/2.0, mineCount); rmPlaceObjectDefAtLoc(goldID, 0, (p4x+e2x)/2.0, (p4z+e2z)/2.0, mineCount); }
   if(players > 5)
 { rmPlaceObjectDefAtLoc(silverID, 0, (p5x+e3x)/2.0, (p5z+e3z)/2.0, mineCount); rmPlaceObjectDefAtLoc(goldID, 0, (p6x+e3x)/2.0, (p6z+e3z)/2.0, mineCount); }
   if(players > 7)
 { rmPlaceObjectDefAtLoc(silverID, 0, (p7x+e4x)/2.0, (p7z+e4z)/2.0, mineCount); rmPlaceObjectDefAtLoc(goldID, 0, (p8x+e4x)/2.0, (p8z+e4z)/2.0, mineCount); }
}
// Elbow islands with gold mines.
   if(minePick == 3 || minePick == 4)
{
// Elbow islands with gold mines
   rmPlaceObjectDefAtLoc(goldID, 0, e1x, e1z, mineCount);
   if(players > 3) rmPlaceObjectDefAtLoc(goldID, 0, e2x, e2z, mineCount);
   if(players > 5) rmPlaceObjectDefAtLoc(goldID, 0, e3x, e3z, mineCount);
   if(players > 7) rmPlaceObjectDefAtLoc(goldID, 0, e4x, e4z, mineCount);
// Connection islands with gold mines
   rmPlaceObjectDefAtLoc(goldID, 0, (p1x+e1x)/2.0, (p1z+e1z)/2.0, mineCount);
   rmPlaceObjectDefAtLoc(goldID, 0, (p2x+e1x)/2.0, (p2z+e1z)/2.0, mineCount);
   if(players > 3)
 { rmPlaceObjectDefAtLoc(goldID, 0, (p3x+e2x)/2.0, (p3z+e2z)/2.0, mineCount); rmPlaceObjectDefAtLoc(goldID, 0, (p4x+e2x)/2.0, (p4z+e2z)/2.0, mineCount); }
   if(players > 5)
 { rmPlaceObjectDefAtLoc(goldID, 0, (p5x+e3x)/2.0, (p5z+e3z)/2.0, mineCount); rmPlaceObjectDefAtLoc(goldID, 0, (p6x+e3x)/2.0, (p6z+e3z)/2.0, mineCount); }
   if(players > 7)
 { rmPlaceObjectDefAtLoc(goldID, 0, (p7x+e4x)/2.0, (p7z+e4z)/2.0, mineCount); rmPlaceObjectDefAtLoc(goldID, 0, (p8x+e4x)/2.0, (p8z+e4z)/2.0, mineCount); }
}
// Last odd player mine since no trade route.
   if(players == 3) rmPlaceObjectDefAtLoc(goldID, 0, p3x, p3z, 2);
   if(players == 5) rmPlaceObjectDefAtLoc(goldID, 0, p5x, p5z, 2);
   if(players == 7) rmPlaceObjectDefAtLoc(goldID, 0, p7x, p7z, 2);
// Bonus islands mines.
   if(useBonusGoldFlag == true) rmPlaceObjectDefAtLoc(mineID, 0, 0.5, 0.5, rmRandInt(islandCount/3, islandCount));

// I6.7 Huntables, Herdables, Player trees and berries.
   rmPlaceObjectDefAtLoc(huntableID, 0, p1x, p1z,2); rmPlaceObjectDefAtLoc(closeHuntableID, 0, p1x, p1z, 1);
   rmPlaceObjectDefAtLoc(huntableID, 0, p2x, p2z,2); rmPlaceObjectDefAtLoc(closeHuntableID, 0, p2x, p2z, 1);
   rmPlaceObjectDefAtLoc(huntableID, 0, e1x, e1z, 2);
   rmPlaceObjectDefAtLoc(huntableID, 0, (p1x+e1x)/2.0, (p1z+e1z)/2.0, 2); rmPlaceObjectDefAtLoc(huntableID, 0, (p2x+e1x)/2.0, (p2z+e1z)/2.0, 2);
   if(players > 2) { rmPlaceObjectDefAtLoc(huntableID, 0, p3x, p3z,2); rmPlaceObjectDefAtLoc(closeHuntableID, 0, p3x, p3z, 1); }
   if(players > 3) { rmPlaceObjectDefAtLoc(huntableID, 0, p4x, p4z,2); rmPlaceObjectDefAtLoc(closeHuntableID, 0, p4x, p4z, 1);
   rmPlaceObjectDefAtLoc(huntableID, 0, e2x, e2z, 2); rmPlaceObjectDefAtLoc(huntableID, 0, (p3x+e2x)/2.0, (p3z+e2z)/2.0, 2);
   rmPlaceObjectDefAtLoc(huntableID, 0, (p4x+e2x)/2.0, (p4z+e2z)/2.0, 2); }
   if(players > 4) { rmPlaceObjectDefAtLoc(huntableID, 0, p5x, p5z,2); rmPlaceObjectDefAtLoc(closeHuntableID, 0, p5x, p5z, 1); }
   if(players > 5) { rmPlaceObjectDefAtLoc(huntableID, 0, p6x, p6z,2); rmPlaceObjectDefAtLoc(closeHuntableID, 0, p6x, p6z, 1);
   rmPlaceObjectDefAtLoc(huntableID, 0, e3x, e3z, 2); rmPlaceObjectDefAtLoc(huntableID, 0, (p5x+e3x)/2.0, (p5z+e3z)/2.0, 2);
   rmPlaceObjectDefAtLoc(huntableID, 0, (p6x+e3x)/2.0, (p6z+e3z)/2.0, 2); }
   if(players > 6) { rmPlaceObjectDefAtLoc(huntableID, 0, p7x, p7z,2); rmPlaceObjectDefAtLoc(closeHuntableID, 0, p7x, p7z, 1); }
   if(players > 7) { rmPlaceObjectDefAtLoc(huntableID, 0, p8x, p8z,2); rmPlaceObjectDefAtLoc(closeHuntableID, 0, p8x, p8z, 1);
   rmPlaceObjectDefAtLoc(huntableID, 0, e4x, e4z, 2); rmPlaceObjectDefAtLoc(huntableID, 0, (p7x+e4x)/2.0, (p7z+e4z)/2.0, 2);
   rmPlaceObjectDefAtLoc(huntableID, 0, (p8x+e4x)/2.0, (p8z+e4z)/2.0, 2); }
   rmPlaceObjectDefAtLoc(islandHuntableID, 0, 0.5, 0.5, rmRandInt(islandCount/3, islandCount));

// Herdables
   rmPlaceObjectDefAtLoc(herdableID, 0, e1x, e1z, 2); 
   rmPlaceObjectDefAtLoc(herdableID, 0, (p1x+e1x)/2.0, (p1z+e1z)/2.0, 2); rmPlaceObjectDefAtLoc(herdableID, 0, (p2x+e1x)/2.0, (p2z+e1z)/2.0, 2);
   if(players == 3) rmPlaceObjectDefAtLoc(herdableID, 0, p3x, p3z,2); 
   if(players > 3) { rmPlaceObjectDefAtLoc(herdableID, 0, e2x, e2z, 4);
   rmPlaceObjectDefAtLoc(herdableID, 0, (p3x+e2x)/2.0, (p3z+e2z)/2.0, 2); rmPlaceObjectDefAtLoc(herdableID, 0, (p4x+e2x)/2.0, (p4z+e2z)/2.0, 2); }
   if(players == 5) rmPlaceObjectDefAtLoc(herdableID, 0, p5x, p5z,2);
   if(players > 5) { rmPlaceObjectDefAtLoc(herdableID, 0, e3x, e3z, 4);
   rmPlaceObjectDefAtLoc(herdableID, 0, (p5x+e3x)/2.0, (p5z+e3z)/2.0, 2); rmPlaceObjectDefAtLoc(herdableID, 0, (p6x+e3x)/2.0, (p6z+e3z)/2.0, 2); }
   if(players == 7) rmPlaceObjectDefAtLoc(herdableID, 0, p7x, p7z,2);
   if(players > 7) { rmPlaceObjectDefAtLoc(herdableID, 0, e4x, e4z, 4);
   rmPlaceObjectDefAtLoc(herdableID, 0, (p7x+e4x)/2.0, (p7z+e4z)/2.0, 2); rmPlaceObjectDefAtLoc(herdableID, 0, (p8x+e4x)/2.0, (p8z+e4z)/2.0, 2); }

// Player trees
   rmPlaceObjectDefAtLoc(treeID, 0, p1x, p1z); 
   rmPlaceObjectDefAtLoc(treeID, 0, p2x, p2z);
   if(players > 2) rmPlaceObjectDefAtLoc(treeID, 0, p3x, p3z); 
   if(players > 3) rmPlaceObjectDefAtLoc(treeID, 0, p4x, p4z); 
   if(players > 4) rmPlaceObjectDefAtLoc(treeID, 0, p5x, p5z); 
   if(players > 5) rmPlaceObjectDefAtLoc(treeID, 0, p6x, p6z); 
   if(players > 6) rmPlaceObjectDefAtLoc(treeID, 0, p7x, p7z); 
   if(players > 7) rmPlaceObjectDefAtLoc(treeID, 0, p8x, p8z);

// Player Berries
   rmPlaceObjectDefAtLoc(berryID, 0, p1x, p1z);  rmPlaceObjectDefAtLoc(berryID, 0, p2x, p2z); rmPlaceObjectDefAtLoc(berryID, 0, e1x, e1z);
   if(players > 2) rmPlaceObjectDefAtLoc(berryID, 0, p3x, p3z); 
   if(players > 3) { rmPlaceObjectDefAtLoc(berryID, 0, p4x, p4z); rmPlaceObjectDefAtLoc(berryID, 0, e2x, e2z); }
   if(players > 4) rmPlaceObjectDefAtLoc(berryID, 0, p5x, p5z); 
   if(players > 5) { rmPlaceObjectDefAtLoc(berryID, 0, p6x, p6z); rmPlaceObjectDefAtLoc(berryID, 0, e3x, e3z); }
   if(players > 6) rmPlaceObjectDefAtLoc(berryID, 0, p7x, p7z); 
   if(players > 7) { rmPlaceObjectDefAtLoc(berryID, 0, p8x, p8z);rmPlaceObjectDefAtLoc(berryID, 0, e4x, e4z); }

// I6.8 Nuggets
// Nuggets for elbow and connecting islands
   if(useNuggetsFlag == true)
  {
   int nugCnt = 3;

// Player nuggets
   rmSetNuggetDifficulty(1, 1);
   rmPlaceObjectDefAtLoc(nuggetID, 0, p1x, p1z, nugCnt);
   rmPlaceObjectDefAtLoc(nuggetID, 0, p2x, p2z, nugCnt);
   if(players > 3) { rmPlaceObjectDefAtLoc(nuggetID, 0, p3x, p3z, nugCnt); rmPlaceObjectDefAtLoc(nuggetID, 0, p4x, p4z, nugCnt); }
   if(players > 5) { rmPlaceObjectDefAtLoc(nuggetID, 0, p5x, p5z, nugCnt); rmPlaceObjectDefAtLoc(nuggetID, 0, p6x, p6z, nugCnt); }
   if(players > 7) { rmPlaceObjectDefAtLoc(nuggetID, 0, p7x, p7z, nugCnt); rmPlaceObjectDefAtLoc(nuggetID, 0, p8x, p8z, nugCnt); }

   nugCnt = 3;
   if(mapSizePick == 2) nugCnt = 4;
   if(mapSizePick == 3) nugCnt = 5;

// For normal start.
   if(rmGetNomadStart() == false)
 {
// Connection island nuggets
   rmSetNuggetDifficulty(1, 2);
   rmPlaceObjectDefAtLoc(nuggetID, 0, (p1x+e1x)/2, (p1z+e1z)/2.0, nugCnt);
   rmPlaceObjectDefAtLoc(nuggetID, 0, (p2x+e1x)/2.0, (p2z+e1z)/2.0, nugCnt);
   if(players > 3) { rmPlaceObjectDefAtLoc(nuggetID, 0, (p3x+e2x)/2.0, (p3z+e2z)/2.0, nugCnt);
   rmPlaceObjectDefAtLoc(nuggetID, 0, (p4x+e2x)/2.0, (p4z+e2z)/2.0, nugCnt); }
   if(players > 5) { rmPlaceObjectDefAtLoc(nuggetID, 0, (p5x+e3x)/2.0, (p5z+e3z)/2.0, nugCnt);
   rmPlaceObjectDefAtLoc(nuggetID, 0, (p6x+e3x)/2.0, (p6z+e3z)/2.0, nugCnt); }
   if(players > 7) { rmPlaceObjectDefAtLoc(nuggetID, 0, (p7x+e4x)/2.0, (p7z+e4z)/2.0, nugCnt);
   rmPlaceObjectDefAtLoc(nuggetID, 0, (p8x+e4x)/2.0, (p8z+e4z)/2.0, nugCnt); }
// Elbow island nuggets
   rmSetNuggetDifficulty(2, 3);
   rmPlaceObjectDefAtLoc(nuggetID, 0, e1x, e1z, nugCnt);
   if(players > 3) rmPlaceObjectDefAtLoc(nuggetID, 0, e2x, e2z, nugCnt);
   if(players > 5) rmPlaceObjectDefAtLoc(nuggetID, 0, e3x, e3z, nugCnt);
   if(players > 7) rmPlaceObjectDefAtLoc(nuggetID, 0, e4x, e4z, nugCnt);

 }
// For Nomad start.
   if(rmGetNomadStart())
 {
// Connection island nuggets
   rmSetNuggetDifficulty(1, 2);
   rmPlaceObjectDefAtLoc(nuggetID, 0, (p1x+e1x)/2, (p1z+e1z)/2, 2*nugCnt);
   rmPlaceObjectDefAtLoc(nuggetID, 0, (p2x+e1x)/2, (p2z+e1z)/2, 2*nugCnt); 
   if((ident3 == 1 || ident4 == 1) && players > 3) { rmPlaceObjectDefAtLoc(nuggetID, 0, (p3x+e2x)/2, (p3z+e2z)/2, 2*nugCnt);
   rmPlaceObjectDefAtLoc(nuggetID, 0, (p4x+e2x)/2, (p4z+e2z)/2, 2*nugCnt); }
   if(ident3 == 0 && ident4 == 0 && players > 3) { rmPlaceObjectDefAtLoc(nuggetID, 0, (p3x+e2x)/2, (p3z+e2z)/2, nugCnt);
   rmPlaceObjectDefAtLoc(nuggetID, 0, (p4x+e2x)/2, (p4z+e2z)/2, nugCnt); }
   if((ident5 == 1 || ident6 == 1) && players > 5) { rmPlaceObjectDefAtLoc(nuggetID, 0, (p5x+e3x)/2, (p5z+e3z)/2, 2*nugCnt);
   rmPlaceObjectDefAtLoc(nuggetID, 0, (p6x+e3x)/2, (p6z+e3z)/2, 2*nugCnt); }
   if(ident5 == 0 && ident6 == 0 && players > 5) { rmPlaceObjectDefAtLoc(nuggetID, 0, (p5x+e3x)/2, (p5z+e3z)/2, nugCnt);
   rmPlaceObjectDefAtLoc(nuggetID, 0, (p6x+e3x)/2, (p6z+e3z)/2, nugCnt); }
   if((ident7 == 1 || ident8 == 1) && players > 7) { rmPlaceObjectDefAtLoc(nuggetID, 0, (p7x+e4x)/2, (p7z+e4z)/2, 2*nugCnt);
   rmPlaceObjectDefAtLoc(nuggetID, 0, (p8x+e4x)/2, (p8z+e4z)/2, 2*nugCnt); }
   if(ident7 == 0 && ident8 == 0 && players > 7) { rmPlaceObjectDefAtLoc(nuggetID, 0, (p7x+e4x)/2, (p7z+e4z)/2, nugCnt);
   rmPlaceObjectDefAtLoc(nuggetID, 0, (p8x+e4x)/2, (p8z+e4z)/2, nugCnt); }
// Elbow island nuggets.
   rmSetNuggetDifficulty(2, 3); 
   rmPlaceObjectDefAtLoc(nuggetID, 0, e1x, e1z, 2*nugCnt);
   if((ident3 == 1 || ident4 == 1) && players > 3) rmPlaceObjectDefAtLoc(nuggetID, 0, e2x, e2z, 2*nugCnt);
   if(ident3 == 0 && ident4 == 0 && players > 3)   rmPlaceObjectDefAtLoc(nuggetID, 0, e2x, e2z, nugCnt);
   if((ident5 == 1 || ident6 == 1) && players > 5) rmPlaceObjectDefAtLoc(nuggetID, 0, e3x, e3z, 2*nugCnt);
   if(ident5 == 0 && ident6 == 0 && players > 5)   rmPlaceObjectDefAtLoc(nuggetID, 0, e3x, e3z, nugCnt);
   if((ident7 == 1 || ident8 == 1) && players > 7) rmPlaceObjectDefAtLoc(nuggetID, 0, e4x, e4z, 2*nugCnt);
   if(ident7 == 0 && ident8 == 0 && players > 7)   rmPlaceObjectDefAtLoc(nuggetID, 0, e4x, e4z, nugCnt);
 }
// Odd player nugget placement.
   rmSetNuggetDifficulty(1, 3); 
   if(players ==3) rmPlaceObjectDefAtLoc(nuggetID, 0, p3x, p3z, nugCnt);
   if(players ==5) rmPlaceObjectDefAtLoc(nuggetID, 0, 0.5, 0.5, nugCnt);
   if(players ==7) rmPlaceObjectDefAtLoc(nuggetID, 0, 0.5, 0.5, nugCnt);

// Bonus island nugget placement.
   rmSetNuggetDifficulty(1, 4);
   rmPlaceObjectDefAtLoc(bonusNuggetID, 0, 0.5, 0.5, islandCount);
 }
// I6.9 Remaining items.
// Random trees
   rmPlaceObjectDefAtLoc(randomTreeID, 0, 0.5, 0.5, 15*players);

// Whales
   rmPlaceObjectDefAtLoc(whaleID, 0, 0.5, 0.5, 4*players);

// Water Flag Fish (Supposedly helps AI decide to fish when fish are by their water flag.)
   rmPlaceObjectDefAtLoc(flagFishID, 0, rmXMetersToFraction(xsVectorGetX(waterFlag1)), rmZMetersToFraction(xsVectorGetZ(waterFlag1)), 1);
   rmPlaceObjectDefAtLoc(flagFishID, 0, rmXMetersToFraction(xsVectorGetX(waterFlag2)), rmZMetersToFraction(xsVectorGetZ(waterFlag2)), 1);
   if(players > 2) rmPlaceObjectDefAtLoc(flagFishID, 0, rmXMetersToFraction(xsVectorGetX(waterFlag3)), rmZMetersToFraction(xsVectorGetZ(waterFlag3)), 1);
   if(players > 3) rmPlaceObjectDefAtLoc(flagFishID, 0, rmXMetersToFraction(xsVectorGetX(waterFlag4)), rmZMetersToFraction(xsVectorGetZ(waterFlag4)), 1);
   if(players > 4) rmPlaceObjectDefAtLoc(flagFishID, 0, rmXMetersToFraction(xsVectorGetX(waterFlag5)), rmZMetersToFraction(xsVectorGetZ(waterFlag5)), 1);
   if(players > 5) rmPlaceObjectDefAtLoc(flagFishID, 0, rmXMetersToFraction(xsVectorGetX(waterFlag6)), rmZMetersToFraction(xsVectorGetZ(waterFlag6)), 1);
   if(players > 6) rmPlaceObjectDefAtLoc(flagFishID, 0, rmXMetersToFraction(xsVectorGetX(waterFlag7)), rmZMetersToFraction(xsVectorGetZ(waterFlag7)), 1);
   if(players > 7) rmPlaceObjectDefAtLoc(flagFishID, 0, rmXMetersToFraction(xsVectorGetX(waterFlag8)), rmZMetersToFraction(xsVectorGetZ(waterFlag8)), 1);

// Fish
   rmPlaceObjectDefAtLoc(fishID, 0, 0.5, 0.5, 5*players);
   rmPlaceObjectDefAtLoc(fish2ID, 0, 0.5, 0.5, 5*players);

   if(useEyeCandyFlag == true)
  {
// Coastal rocks
   rmPlaceObjectDefAtLoc(rockID, 0, 0.5, 0.5, 4*players);

// Duck family
   rmPlaceObjectDefAtLoc(ducksID, 0, 0.5, 0.5, 4*players);

// Water plants
   rmPlaceObjectDefAtLoc(plantsID, 0, 0.5, 0.5, 4*players);

// Shipwreck
   rmPlaceObjectDefAtLoc(shipwreckID, 0, 0.5, 0.5, 4*players);
  }
// Forests
   int forestTreeID = 0;
   int numTries=12*players;
   int failCount=0;
   for (i=0; <numTries)
 {   
   int forest=rmCreateArea("forest "+i);
   rmSetAreaWarnFailure(forest, false);
   rmSetAreaSize(forest, rmAreaTilesToFraction(300), rmAreaTilesToFraction(400));
   rmSetAreaForestType(forest, forestType);
   rmSetAreaForestDensity(forest, 0.9); // was 7
   rmSetAreaForestClumpiness(forest, 0.6); // was .4
   rmSetAreaForestUnderbrush(forest, 0.2); // was 0
   rmSetAreaMinBlobs(forest, 1);
   rmSetAreaMaxBlobs(forest, 5);
   rmSetAreaMinBlobDistance(forest, 16.0);
   rmSetAreaMaxBlobDistance(forest, 40.0);
   rmSetAreaCoherence(forest, 0.6); // was .4
   rmSetAreaSmoothDistance(forest, 5); // was 10
   rmAddAreaToClass(forest, rmClassID("classForest"));
   rmAddAreaConstraint(forest, forestConstraint);
   rmAddAreaConstraint(forest, avoidSilver);
   rmAddAreaConstraint(forest, avoidGold);
   rmAddAreaConstraint(forest, avoidTC15);
   rmAddAreaConstraint(forest, avoidCW);
   rmAddAreaConstraint(forest, avoidAll);
   rmAddAreaConstraint(forest, avoidTradeRoute);
   rmAddAreaConstraint(forest, avoidNatives);
   rmAddAreaConstraint(forest, avoidNugget);
   rmAddAreaConstraint(forest, avoidSurprise);

   if(rmBuildArea(forest)==false)
 {
   // Stop trying once we fail 3 times in a row.
   failCount++;
   if(failCount==5)
   break;
 }
   else
   failCount=0; 
 }
// Bonus island special prop
   if(useBonusEyeCandyFlag == true) rmPlaceObjectDefAtLoc(specialID, 0, 0.5, 0.5, 1);

// Bonus island crates
   if(useBonusCratesFlag == true) rmPlaceObjectDefAtLoc(crateID, 0, 0.5, 0.5, islandCount-1);

// Place bison carcass grouping.
   if(useEyeCandyFlag == true) rmPlaceGroupingAtLoc(groupID, 0, p1x, p1z, 1);

// Place BFG
   if(useBFGFlag == true && useBFGwithBaseFlag == true)  rmPlaceGroupingAtLoc(BFGID, 0, 0.5, 0.5);
   if(useBFGFlag == true && useBFGwithBaseFlag == false) rmPlaceObjectDefAtLoc(BFG1ID, 0, 0.5, 0.5);

/* I7.0 Triggers */  rmSetStatusText("",0.9);

// I7.1 Create Triggers.

   rmCreateTrigger("StartMessage");
   rmCreateTrigger("FPSMeasure");
   rmCreateTrigger("FPSDelay");
   rmCreateTrigger("Pause");
   rmCreateTrigger("MovePirate1Leg1"); 
   rmCreateTrigger("MovePirate1Leg2");
   rmCreateTrigger("MovePirate1Leg3");
   rmCreateTrigger("MovePirate1Leg4");
   rmCreateTrigger("MovePirate2Leg1"); 
   rmCreateTrigger("MovePirate2Leg2");
   rmCreateTrigger("MovePirate2Leg3");
   rmCreateTrigger("MovePirate2Leg4");
   rmCreateTrigger("MovePirate3Leg1"); 
   rmCreateTrigger("MovePirate3Leg2");
   rmCreateTrigger("MovePirate3Leg3");
   rmCreateTrigger("MovePirate3Leg4");
   rmCreateTrigger("MovePirate4Leg1"); 
   rmCreateTrigger("MovePirate4Leg2");
   rmCreateTrigger("MovePirate4Leg3");
   rmCreateTrigger("MovePirate4Leg4");
   for(i=1; <= players) rmCreateTrigger("ConvertToPlayer"+i);
/*
   rmCreateTrigger("ConvertToPlayer1");
   rmCreateTrigger("ConvertToPlayer2");
   rmCreateTrigger("ConvertToPlayer3");
   rmCreateTrigger("ConvertToPlayer4");
   rmCreateTrigger("ConvertToPlayer5");
   rmCreateTrigger("ConvertToPlayer6");
   rmCreateTrigger("ConvertToPlayer7");
   rmCreateTrigger("ConvertToPlayer8");
*/
// I7.2 Start trigger
   string messageText = "Welcome to Dogleg Islands by Jugit. Version: " + version + ". ";
   if(multiPlayerFlag == false)
 {
   messageText = messageText + "The dogleg island";
   if(players < 4) messageText = messageText + " on this map is ";   
   if(players > 3) messageText = messageText + "s on this map are ";
   if(mapSizePick == 1) messageText = messageText + "small in size.";
   if(mapSizePick == 2) messageText = messageText + "medium in size.";
   if(mapSizePick == 3) messageText = messageText + "large in size.";
 }
   if(rmGetNomadStart()) { messageText = "Human players get a landing party. Computer players get a covered wagon. "; }
   if(multiPlayerFlag == true) { messageText = messageText + "Multiplayer selected or detected."; }
   if(watchPiratesFlag == true)
  {
   int s11x = 100*ps11x; int s11z = 100*ps11z; int s12x = 100*ps12x; int s12z = 100*ps12z;
   int s13x = 100*ps13x; int s13z = 100*ps13z; int s14x = 100*ps14x; int s14z = 100*ps14z;
   int s21x = 100*ps21x; int s21z = 100*ps21z; int s22x = 100*ps22x; int s22z = 100*ps22z;
   int s23x = 100*ps23x; int s23z = 100*ps23z; int s24x = 100*ps24x; int s24z = 100*ps24z;
   int s31x = 100*ps31x; int s31z = 100*ps31z; int s32x = 100*ps32x; int s32z = 100*ps32z;
   int s33x = 100*ps33x; int s33z = 100*ps33z; int s34x = 100*ps34x; int s34z = 100*ps34z;
   int s41x = 100*ps41x; int s41z = 100*ps41z; int s42x = 100*ps42x; int s42z = 100*ps42z;
   int s43x = 100*ps43x; int s43z = 100*ps43z; int s44x = 100*ps44x; int s44z = 100*ps44z;
   messageText =                               "S1." + s11x + "." + s11z + ",." + s12x + "." + s12z 
                                             + "; ." + s13x + "." + s13z + ",." + s14x + "." + s14z + ". ";
   if(players > 2) messageText = messageText + "S2." + s21x + "." + s21z + ",." + s22x + "." + s22z
                                             + "; ." + s23x + "." + s23z + ",." + s24x + "." + s24z + ". ";
   if(players > 4) messageText = messageText + "S3." + s31x + "." + s31z + ",." + s32x + "." + s32z
                                             + "; ." + s33x + "." + s33z + ",." + s34x + "." + s34z + ". ";
   if(players > 6) messageText = messageText + "S4." + s41x + "." + s41z + ",." + s42x + "." + s42z
                                             + "; ." + s43x + "." + s43z + ",." + s44x + "." + s44z + ". ";
  }
   rmSwitchToTrigger(rmTriggerID("StartMessage"));
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", 7);
   rmAddTriggerEffect("Message"); rmSetTriggerEffectParam("Text",messageText); rmSetTriggerEffectParamInt("Timeout", 10000);
   rmAddTriggerEffect("Sound Filename"); rmSetTriggerEffectParam("Sound", "\cinematics\09 a\Gun.mp3");
   if(useCountdownFlag == true)
 {
   rmAddTriggerEffect("Counter:Add Timer");
   rmSetTriggerEffectParam("Name","Pirate move");
   rmSetTriggerEffectParamInt("Start",pirate1stMoveTime-5);
   rmSetTriggerEffectParamInt("Stop",1);
   rmSetTriggerEffectParam("Msg","Time to pirates next move");
 }
   if(revealMapFlag == true)
 { 
   rmAddTriggerEffect("Render Fog/Black Map");
   rmSetTriggerEffectParam("Black", "false");
   rmSetTriggerEffectParam("Fog", "false");
  }
// I7.4  FPS triggers.

   if(useFPSCounterFlag == true)
 {
   messageText = "Time to measure the FPS. Unpause and take measurement.";
   rmSwitchToTrigger(rmTriggerID("FPSMeasure")); rmSetTriggerActive(true);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", 25);
   rmAddTriggerEffect("Message"); rmSetTriggerEffectParam("Text",messageText); rmSetTriggerEffectParamInt("Timeout", 10000);
   rmAddTriggerEffect("Sound Filename"); rmSetTriggerEffectParam("Sound", "\cinematics\09 a\Gun.mp3");
   rmAddTriggerEffect("Counter:Add Timer");
   rmSetTriggerEffectParam("Name","FPS Measure");
   rmSetTriggerEffectParamInt("Start", 600);
   rmSetTriggerEffectParamInt("Stop", 1);
   rmSetTriggerEffectParam("Msg","Time to next FPS measure");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("Pause"));
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("FPSDelay"));

   rmSwitchToTrigger(rmTriggerID("Pause")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", 2);
   rmAddTriggerEffect("Pause Game");
   rmSetTriggerEffectParam("Pause", "true");

   rmSwitchToTrigger(rmTriggerID("FPSDelay")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", 600);
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("FPSMeasure"));
   rmAddTriggerEffect("Disable Trigger"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("StartMessage"));
 }
// Pirate ship triggers.
   if(usePiratesFlag == true)
 {
// Move pirate ship 1 on leg 1.
   rmSwitchToTrigger(rmTriggerID("MovePirate1Leg1")); rmSetTriggerActive(true);
   rmAddTriggerCondition("Timer");
   rmSetTriggerConditionParamInt("Param1", pirate1stMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate1Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps11x)+",0,"+rmZFractionToMeters(ps11z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Disable Trigger"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("StartMessage"));
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate1Leg2"));
   if(useCountdownFlag == true)
 {
   rmAddTriggerEffect("Counter:Add Timer");
   rmSetTriggerEffectParam("Name","Pirate move");
   rmSetTriggerEffectParamInt("Start",pirateMoveTime);
   rmSetTriggerEffectParamInt("Stop",1);
   rmSetTriggerEffectParam("Msg","Time to pirates next move");
 }
// Move pirate ship 1 on leg 2.
   rmSwitchToTrigger(rmTriggerID("MovePirate1Leg2")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", pirateMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate1Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps12x)+",0,"+rmZFractionToMeters(ps12z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate1Leg3"));
   if(useCountdownFlag == true)
 {
   rmAddTriggerEffect("Counter:Add Timer");
   rmSetTriggerEffectParam("Name","Pirate move");
   rmSetTriggerEffectParamInt("Start",pirateMoveTime);
   rmSetTriggerEffectParamInt("Stop",1);
   rmSetTriggerEffectParam("Msg","Time to pirates next move");
  }
// Move pirate ship 1 on leg 3.
   rmSwitchToTrigger(rmTriggerID("MovePirate1Leg3")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", pirateMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate1Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps13x)+",0,"+rmZFractionToMeters(ps13z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate1Leg4"));
   if(useCountdownFlag == true)
 {
   rmAddTriggerEffect("Counter:Add Timer");
   rmSetTriggerEffectParam("Name","Pirate move");
   rmSetTriggerEffectParamInt("Start",pirateMoveTime);
   rmSetTriggerEffectParamInt("Stop",1);
   rmSetTriggerEffectParam("Msg","Time to pirates next move");
 }
// Move pirate ship 1 on leg 4.
   rmSwitchToTrigger(rmTriggerID("MovePirate1Leg4")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", pirateMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate1Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps14x)+",0,"+rmZFractionToMeters(ps14z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate1Leg1"));
   if(useCountdownFlag == true)
 {
   rmAddTriggerEffect("Counter:Add Timer");
   rmSetTriggerEffectParam("Name","Pirate move");
   rmSetTriggerEffectParamInt("Start",pirateMoveTime);
   rmSetTriggerEffectParamInt("Stop",1);
   rmSetTriggerEffectParam("Msg","Time to pirates next move");
 }
// Move pirate ship 2 on leg 1.
   if(players > 2)
 {
   rmSwitchToTrigger(rmTriggerID("MovePirate2Leg1")); rmSetTriggerActive(true);
   rmAddTriggerCondition("Timer");
   rmSetTriggerConditionParamInt("Param1", 1+pirate1stMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate2Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps21x)+",0,"+rmZFractionToMeters(ps21z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate2Leg2"));

// Move pirate ship 2 on leg 2.
   rmSwitchToTrigger(rmTriggerID("MovePirate2Leg2")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", pirateMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate2Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps22x)+",0,"+rmZFractionToMeters(ps22z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate2Leg3"));

// Move pirate ship 2 on leg 3.
   rmSwitchToTrigger(rmTriggerID("MovePirate2Leg3")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", pirateMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate2Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps23x)+",0,"+rmZFractionToMeters(ps23z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate2Leg4"));

// Move pirate ship 2 on leg 4.
   rmSwitchToTrigger(rmTriggerID("MovePirate2Leg4")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", pirateMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate2Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps24x)+",0,"+rmZFractionToMeters(ps24z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate2Leg1"));
 }
// Move pirate ship 3 on leg 1.
   if(players > 4)
 {
   rmSwitchToTrigger(rmTriggerID("MovePirate3Leg1")); rmSetTriggerActive(true);
   rmAddTriggerCondition("Timer");
   rmSetTriggerConditionParamInt("Param1", 2+pirate1stMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate3Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps31x)+",0,"+rmZFractionToMeters(ps31z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate3Leg2"));

// Move pirate ship 3 on leg 2.
   rmSwitchToTrigger(rmTriggerID("MovePirate3Leg2")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", pirateMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate3Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps32x)+",0,"+rmZFractionToMeters(ps32z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate3Leg3"));

// Move pirate ship 3 on leg 3.
   rmSwitchToTrigger(rmTriggerID("MovePirate3Leg3")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", pirateMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate3Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps33x)+",0,"+rmZFractionToMeters(ps33z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate3Leg4"));

// Move pirate ship 3 on leg 4.
   rmSwitchToTrigger(rmTriggerID("MovePirate3Leg4")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", pirateMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate3Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps34x)+",0,"+rmZFractionToMeters(ps34z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate3Leg1"));
 }
// Move pirate ship 4 on leg 1.
   if(players > 6)
 {
   rmSwitchToTrigger(rmTriggerID("MovePirate4Leg1")); rmSetTriggerActive(true);
   rmAddTriggerCondition("Timer");
   rmSetTriggerConditionParamInt("Param1", 3+pirate1stMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate4Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps41x)+",0,"+rmZFractionToMeters(ps41z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate4Leg2"));

// Move pirate ship 4 on leg 2.
   rmSwitchToTrigger(rmTriggerID("MovePirate4Leg2")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", pirateMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate4Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps42x)+",0,"+rmZFractionToMeters(ps42z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate4Leg3"));

// Move pirate ship 4 on leg 3.
   rmSwitchToTrigger(rmTriggerID("MovePirate4Leg3")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", pirateMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate4Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps43x)+",0,"+rmZFractionToMeters(ps43z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate2Leg4"));

// Move pirate ship 4 on leg 4.
   rmSwitchToTrigger(rmTriggerID("MovePirate4Leg4")); rmSetTriggerActive(false);
   rmAddTriggerCondition("Timer"); rmSetTriggerConditionParamInt("Param1", pirateMoveTime);
   rmAddTriggerEffect("Move To Point");
   rmSetTriggerEffectParamInt("SrcObject", pirate4Select);
   rmSetTriggerEffectParam("DstPoint", rmXFractionToMeters(ps44x)+",0,"+rmZFractionToMeters(ps44z));
   if(useAttackMoveFlag == true) rmSetTriggerEffectParam("AttackMove", "true");
   rmAddTriggerEffect("Fire Event"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("MovePirate4Leg1"));
 }
}
// I7.5 Surprise triggers
   if(useSurpriseFlag == true)
{
   for(i=1; <= players)
  {
   rmSwitchToTrigger(rmTriggerID("ConvertToPlayer"+i));
   rmSetTriggerActive(true);
   rmAddTriggerCondition("Units In LOS");
   rmSetTriggerConditionParamInt("SrcObject", surpriseSelect);
   rmSetTriggerConditionParamInt("PlayerID", i);
   rmAddTriggerEffect("Convert");
   rmSetTriggerEffectParamInt("SrcObject", surpriseSelect);
   rmSetTriggerEffectParamInt("PlayerID", i);
   rmAddTriggerEffect("Sound Filename"); rmSetTriggerEffectParam("Sound", "\cinematics\02 A\Horse.mp3");
   for(j=1; <= players)
   {
   rmAddTriggerEffect("Disable Trigger"); rmSetTriggerEffectParamInt("EventID", rmTriggerID("ConvertToPlayer"+j));
   }
  }
 }
 /* Finished */  rmSetStatusText("",0.99);
}  
